// Code generated by 'yaegi extract syscall'. DO NOT EDIT.

//go:build go1.22 && !solaris
// +build go1.22,!solaris

package syscall

import (
	"go/constant"
	"go/token"
	"reflect"
	"syscall"
)

func init() {
	Symbols["syscall/syscall"] = map[string]reflect.Value{
		// function, constant and variable definitions
		"AF_802":                        reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"AF_APPLETALK":                  reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"AF_CCITT":                      reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"AF_CHAOS":                      reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"AF_DATAKIT":                    reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"AF_DECnet":                     reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"AF_DLI":                        reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"AF_ECMA":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"AF_FILE":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"AF_GOSIP":                      reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"AF_HYLINK":                     reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"AF_IMPLINK":                    reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"AF_INET":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"AF_INET6":                      reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"AF_INET_OFFLOAD":               reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"AF_IPX":                        reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"AF_KEY":                        reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"AF_LAT":                        reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"AF_LINK":                       reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"AF_LOCAL":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"AF_MAX":                        reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"AF_NBS":                        reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"AF_NCA":                        reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"AF_NIT":                        reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"AF_NS":                         reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"AF_OSI":                        reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"AF_OSINET":                     reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"AF_PACKET":                     reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"AF_POLICY":                     reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"AF_PUP":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"AF_ROUTE":                      reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"AF_SNA":                        reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"AF_TRILL":                      reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"AF_UNIX":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"AF_UNSPEC":                     reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"AF_X25":                        reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"ARPHRD_ARCNET":                 reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"ARPHRD_ATM":                    reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"ARPHRD_AX25":                   reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"ARPHRD_CHAOS":                  reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"ARPHRD_EETHER":                 reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ARPHRD_ETHER":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"ARPHRD_FC":                     reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"ARPHRD_FRAME":                  reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"ARPHRD_HDLC":                   reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"ARPHRD_IB":                     reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"ARPHRD_IEEE802":                reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"ARPHRD_IPATM":                  reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"ARPHRD_METRICOM":               reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"ARPHRD_TUNNEL":                 reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"Accept":                        reflect.ValueOf(syscall.Accept),
		"Accept4":                       reflect.ValueOf(syscall.Accept4),
		"Access":                        reflect.ValueOf(syscall.Access),
		"Adjtime":                       reflect.ValueOf(syscall.Adjtime),
		"B0":                            reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"B110":                          reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"B115200":                       reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"B1200":                         reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"B134":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"B150":                          reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"B153600":                       reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"B1800":                         reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"B19200":                        reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"B200":                          reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"B230400":                       reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"B2400":                         reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"B300":                          reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"B307200":                       reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"B38400":                        reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"B460800":                       reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"B4800":                         reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"B50":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"B57600":                        reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"B600":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"B75":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"B76800":                        reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"B921600":                       reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"B9600":                         reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"BIOCFLUSH":                     reflect.ValueOf(constant.MakeFromLiteral("536887912", token.INT, 0)),
		"BIOCGBLEN":                     reflect.ValueOf(constant.MakeFromLiteral("1074020966", token.INT, 0)),
		"BIOCGDLT":                      reflect.ValueOf(constant.MakeFromLiteral("1074020970", token.INT, 0)),
		"BIOCGDLTLIST":                  reflect.ValueOf(constant.MakeFromLiteral("-1072676233", token.INT, 0)),
		"BIOCGDLTLIST32":                reflect.ValueOf(constant.MakeFromLiteral("-1073200521", token.INT, 0)),
		"BIOCGETIF":                     reflect.ValueOf(constant.MakeFromLiteral("1075855979", token.INT, 0)),
		"BIOCGETLIF":                    reflect.ValueOf(constant.MakeFromLiteral("1081623147", token.INT, 0)),
		"BIOCGHDRCMPLT":                 reflect.ValueOf(constant.MakeFromLiteral("1074020980", token.INT, 0)),
		"BIOCGRTIMEOUT":                 reflect.ValueOf(constant.MakeFromLiteral("1074807419", token.INT, 0)),
		"BIOCGRTIMEOUT32":               reflect.ValueOf(constant.MakeFromLiteral("1074283131", token.INT, 0)),
		"BIOCGSEESENT":                  reflect.ValueOf(constant.MakeFromLiteral("1074020984", token.INT, 0)),
		"BIOCGSTATS":                    reflect.ValueOf(constant.MakeFromLiteral("1082147439", token.INT, 0)),
		"BIOCGSTATSOLD":                 reflect.ValueOf(constant.MakeFromLiteral("1074283119", token.INT, 0)),
		"BIOCIMMEDIATE":                 reflect.ValueOf(constant.MakeFromLiteral("-2147204496", token.INT, 0)),
		"BIOCPROMISC":                   reflect.ValueOf(constant.MakeFromLiteral("536887913", token.INT, 0)),
		"BIOCSBLEN":                     reflect.ValueOf(constant.MakeFromLiteral("-1073462682", token.INT, 0)),
		"BIOCSDLT":                      reflect.ValueOf(constant.MakeFromLiteral("-2147204490", token.INT, 0)),
		"BIOCSETF":                      reflect.ValueOf(constant.MakeFromLiteral("-2146418073", token.INT, 0)),
		"BIOCSETF32":                    reflect.ValueOf(constant.MakeFromLiteral("-2146942361", token.INT, 0)),
		"BIOCSETIF":                     reflect.ValueOf(constant.MakeFromLiteral("-2145369492", token.INT, 0)),
		"BIOCSETLIF":                    reflect.ValueOf(constant.MakeFromLiteral("-2139602324", token.INT, 0)),
		"BIOCSHDRCMPLT":                 reflect.ValueOf(constant.MakeFromLiteral("-2147204491", token.INT, 0)),
		"BIOCSRTIMEOUT":                 reflect.ValueOf(constant.MakeFromLiteral("-2146418054", token.INT, 0)),
		"BIOCSRTIMEOUT32":               reflect.ValueOf(constant.MakeFromLiteral("-2146942342", token.INT, 0)),
		"BIOCSSEESENT":                  reflect.ValueOf(constant.MakeFromLiteral("-2147204487", token.INT, 0)),
		"BIOCSTCPF":                     reflect.ValueOf(constant.MakeFromLiteral("-2146418062", token.INT, 0)),
		"BIOCSUDPF":                     reflect.ValueOf(constant.MakeFromLiteral("-2146418061", token.INT, 0)),
		"BIOCVERSION":                   reflect.ValueOf(constant.MakeFromLiteral("1074020977", token.INT, 0)),
		"BPF_A":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_ABS":                       reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"BPF_ADD":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_ALIGNMENT":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"BPF_ALU":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"BPF_AND":                       reflect.ValueOf(constant.MakeFromLiteral("80", token.INT, 0)),
		"BPF_B":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_DFLTBUFSIZE":               reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"BPF_DIV":                       reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"BPF_H":                         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"BPF_IMM":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_IND":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"BPF_JA":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_JEQ":                       reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_JGE":                       reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"BPF_JGT":                       reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"BPF_JMP":                       reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"BPF_JSET":                      reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"BPF_K":                         reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_LD":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_LDX":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"BPF_LEN":                       reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"BPF_LSH":                       reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"BPF_MAJOR_VERSION":             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"BPF_MAXBUFSIZE":                reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"BPF_MAXINSNS":                  reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"BPF_MEM":                       reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"BPF_MEMWORDS":                  reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_MINBUFSIZE":                reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"BPF_MINOR_VERSION":             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"BPF_MISC":                      reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"BPF_MSH":                       reflect.ValueOf(constant.MakeFromLiteral("160", token.INT, 0)),
		"BPF_MUL":                       reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"BPF_NEG":                       reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"BPF_OR":                        reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"BPF_RELEASE":                   reflect.ValueOf(constant.MakeFromLiteral("199606", token.INT, 0)),
		"BPF_RET":                       reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"BPF_RSH":                       reflect.ValueOf(constant.MakeFromLiteral("112", token.INT, 0)),
		"BPF_ST":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"BPF_STX":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"BPF_SUB":                       reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_TAX":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_TXA":                       reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"BPF_W":                         reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_X":                         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"BRKINT":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"Bind":                          reflect.ValueOf(syscall.Bind),
		"BytePtrFromString":             reflect.ValueOf(syscall.BytePtrFromString),
		"ByteSliceFromString":           reflect.ValueOf(syscall.ByteSliceFromString),
		"CFLUSH":                        reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"CLOCAL":                        reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"CREAD":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"CS5":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"CS6":                           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"CS7":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"CS8":                           reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"CSIZE":                         reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"CSTART":                        reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"CSTOP":                         reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"CSTOPB":                        reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"CSUSP":                         reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"CSWTCH":                        reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"Chdir":                         reflect.ValueOf(syscall.Chdir),
		"Chmod":                         reflect.ValueOf(syscall.Chmod),
		"Chown":                         reflect.ValueOf(syscall.Chown),
		"Chroot":                        reflect.ValueOf(syscall.Chroot),
		"Clearenv":                      reflect.ValueOf(syscall.Clearenv),
		"Close":                         reflect.ValueOf(syscall.Close),
		"CloseOnExec":                   reflect.ValueOf(syscall.CloseOnExec),
		"CmsgLen":                       reflect.ValueOf(syscall.CmsgLen),
		"CmsgSpace":                     reflect.ValueOf(syscall.CmsgSpace),
		"Connect":                       reflect.ValueOf(syscall.Connect),
		"DLT_AIRONET_HEADER":            reflect.ValueOf(constant.MakeFromLiteral("120", token.INT, 0)),
		"DLT_APPLE_IP_OVER_IEEE1394":    reflect.ValueOf(constant.MakeFromLiteral("138", token.INT, 0)),
		"DLT_ARCNET":                    reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"DLT_ARCNET_LINUX":              reflect.ValueOf(constant.MakeFromLiteral("129", token.INT, 0)),
		"DLT_ATM_CLIP":                  reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"DLT_ATM_RFC1483":               reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"DLT_AURORA":                    reflect.ValueOf(constant.MakeFromLiteral("126", token.INT, 0)),
		"DLT_AX25":                      reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"DLT_BACNET_MS_TP":              reflect.ValueOf(constant.MakeFromLiteral("165", token.INT, 0)),
		"DLT_CHAOS":                     reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"DLT_CISCO_IOS":                 reflect.ValueOf(constant.MakeFromLiteral("118", token.INT, 0)),
		"DLT_C_HDLC":                    reflect.ValueOf(constant.MakeFromLiteral("104", token.INT, 0)),
		"DLT_DOCSIS":                    reflect.ValueOf(constant.MakeFromLiteral("143", token.INT, 0)),
		"DLT_ECONET":                    reflect.ValueOf(constant.MakeFromLiteral("115", token.INT, 0)),
		"DLT_EN10MB":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"DLT_EN3MB":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"DLT_ENC":                       reflect.ValueOf(constant.MakeFromLiteral("109", token.INT, 0)),
		"DLT_ERF_ETH":                   reflect.ValueOf(constant.MakeFromLiteral("175", token.INT, 0)),
		"DLT_ERF_POS":                   reflect.ValueOf(constant.MakeFromLiteral("176", token.INT, 0)),
		"DLT_FDDI":                      reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"DLT_FRELAY":                    reflect.ValueOf(constant.MakeFromLiteral("107", token.INT, 0)),
		"DLT_GCOM_SERIAL":               reflect.ValueOf(constant.MakeFromLiteral("173", token.INT, 0)),
		"DLT_GCOM_T1E1":                 reflect.ValueOf(constant.MakeFromLiteral("172", token.INT, 0)),
		"DLT_GPF_F":                     reflect.ValueOf(constant.MakeFromLiteral("171", token.INT, 0)),
		"DLT_GPF_T":                     reflect.ValueOf(constant.MakeFromLiteral("170", token.INT, 0)),
		"DLT_GPRS_LLC":                  reflect.ValueOf(constant.MakeFromLiteral("169", token.INT, 0)),
		"DLT_HDLC":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"DLT_HHDLC":                     reflect.ValueOf(constant.MakeFromLiteral("121", token.INT, 0)),
		"DLT_HIPPI":                     reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"DLT_IBM_SN":                    reflect.ValueOf(constant.MakeFromLiteral("146", token.INT, 0)),
		"DLT_IBM_SP":                    reflect.ValueOf(constant.MakeFromLiteral("145", token.INT, 0)),
		"DLT_IEEE802":                   reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"DLT_IEEE802_11":                reflect.ValueOf(constant.MakeFromLiteral("105", token.INT, 0)),
		"DLT_IEEE802_11_RADIO":          reflect.ValueOf(constant.MakeFromLiteral("127", token.INT, 0)),
		"DLT_IEEE802_11_RADIO_AVS":      reflect.ValueOf(constant.MakeFromLiteral("163", token.INT, 0)),
		"DLT_IPNET":                     reflect.ValueOf(constant.MakeFromLiteral("226", token.INT, 0)),
		"DLT_IPOIB":                     reflect.ValueOf(constant.MakeFromLiteral("162", token.INT, 0)),
		"DLT_IP_OVER_FC":                reflect.ValueOf(constant.MakeFromLiteral("122", token.INT, 0)),
		"DLT_JUNIPER_ATM1":              reflect.ValueOf(constant.MakeFromLiteral("137", token.INT, 0)),
		"DLT_JUNIPER_ATM2":              reflect.ValueOf(constant.MakeFromLiteral("135", token.INT, 0)),
		"DLT_JUNIPER_CHDLC":             reflect.ValueOf(constant.MakeFromLiteral("181", token.INT, 0)),
		"DLT_JUNIPER_ES":                reflect.ValueOf(constant.MakeFromLiteral("132", token.INT, 0)),
		"DLT_JUNIPER_ETHER":             reflect.ValueOf(constant.MakeFromLiteral("178", token.INT, 0)),
		"DLT_JUNIPER_FRELAY":            reflect.ValueOf(constant.MakeFromLiteral("180", token.INT, 0)),
		"DLT_JUNIPER_GGSN":              reflect.ValueOf(constant.MakeFromLiteral("133", token.INT, 0)),
		"DLT_JUNIPER_MFR":               reflect.ValueOf(constant.MakeFromLiteral("134", token.INT, 0)),
		"DLT_JUNIPER_MLFR":              reflect.ValueOf(constant.MakeFromLiteral("131", token.INT, 0)),
		"DLT_JUNIPER_MLPPP":             reflect.ValueOf(constant.MakeFromLiteral("130", token.INT, 0)),
		"DLT_JUNIPER_MONITOR":           reflect.ValueOf(constant.MakeFromLiteral("164", token.INT, 0)),
		"DLT_JUNIPER_PIC_PEER":          reflect.ValueOf(constant.MakeFromLiteral("174", token.INT, 0)),
		"DLT_JUNIPER_PPP":               reflect.ValueOf(constant.MakeFromLiteral("179", token.INT, 0)),
		"DLT_JUNIPER_PPPOE":             reflect.ValueOf(constant.MakeFromLiteral("167", token.INT, 0)),
		"DLT_JUNIPER_PPPOE_ATM":         reflect.ValueOf(constant.MakeFromLiteral("168", token.INT, 0)),
		"DLT_JUNIPER_SERVICES":          reflect.ValueOf(constant.MakeFromLiteral("136", token.INT, 0)),
		"DLT_LINUX_IRDA":                reflect.ValueOf(constant.MakeFromLiteral("144", token.INT, 0)),
		"DLT_LINUX_LAPD":                reflect.ValueOf(constant.MakeFromLiteral("177", token.INT, 0)),
		"DLT_LINUX_SLL":                 reflect.ValueOf(constant.MakeFromLiteral("113", token.INT, 0)),
		"DLT_LOOP":                      reflect.ValueOf(constant.MakeFromLiteral("108", token.INT, 0)),
		"DLT_LTALK":                     reflect.ValueOf(constant.MakeFromLiteral("114", token.INT, 0)),
		"DLT_MTP2":                      reflect.ValueOf(constant.MakeFromLiteral("140", token.INT, 0)),
		"DLT_MTP2_WITH_PHDR":            reflect.ValueOf(constant.MakeFromLiteral("139", token.INT, 0)),
		"DLT_MTP3":                      reflect.ValueOf(constant.MakeFromLiteral("141", token.INT, 0)),
		"DLT_NULL":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"DLT_PCI_EXP":                   reflect.ValueOf(constant.MakeFromLiteral("125", token.INT, 0)),
		"DLT_PFLOG":                     reflect.ValueOf(constant.MakeFromLiteral("117", token.INT, 0)),
		"DLT_PFSYNC":                    reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"DLT_PPP":                       reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"DLT_PPP_BSDOS":                 reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"DLT_PPP_PPPD":                  reflect.ValueOf(constant.MakeFromLiteral("166", token.INT, 0)),
		"DLT_PRISM_HEADER":              reflect.ValueOf(constant.MakeFromLiteral("119", token.INT, 0)),
		"DLT_PRONET":                    reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"DLT_RAW":                       reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"DLT_RAWAF_MASK":                reflect.ValueOf(constant.MakeFromLiteral("35913728", token.INT, 0)),
		"DLT_RIO":                       reflect.ValueOf(constant.MakeFromLiteral("124", token.INT, 0)),
		"DLT_SCCP":                      reflect.ValueOf(constant.MakeFromLiteral("142", token.INT, 0)),
		"DLT_SLIP":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"DLT_SLIP_BSDOS":                reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"DLT_SUNATM":                    reflect.ValueOf(constant.MakeFromLiteral("123", token.INT, 0)),
		"DLT_SYMANTEC_FIREWALL":         reflect.ValueOf(constant.MakeFromLiteral("99", token.INT, 0)),
		"DLT_TZSP":                      reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"Dup":                           reflect.ValueOf(syscall.Dup),
		"E2BIG":                         reflect.ValueOf(syscall.E2BIG),
		"EACCES":                        reflect.ValueOf(syscall.EACCES),
		"EADDRINUSE":                    reflect.ValueOf(syscall.EADDRINUSE),
		"EADDRNOTAVAIL":                 reflect.ValueOf(syscall.EADDRNOTAVAIL),
		"EADV":                          reflect.ValueOf(syscall.EADV),
		"EAFNOSUPPORT":                  reflect.ValueOf(syscall.EAFNOSUPPORT),
		"EAGAIN":                        reflect.ValueOf(syscall.EAGAIN),
		"EALREADY":                      reflect.ValueOf(syscall.EALREADY),
		"EBADE":                         reflect.ValueOf(syscall.EBADE),
		"EBADF":                         reflect.ValueOf(syscall.EBADF),
		"EBADFD":                        reflect.ValueOf(syscall.EBADFD),
		"EBADMSG":                       reflect.ValueOf(syscall.EBADMSG),
		"EBADR":                         reflect.ValueOf(syscall.EBADR),
		"EBADRQC":                       reflect.ValueOf(syscall.EBADRQC),
		"EBADSLT":                       reflect.ValueOf(syscall.EBADSLT),
		"EBFONT":                        reflect.ValueOf(syscall.EBFONT),
		"EBUSY":                         reflect.ValueOf(syscall.EBUSY),
		"ECANCELED":                     reflect.ValueOf(syscall.ECANCELED),
		"ECHILD":                        reflect.ValueOf(syscall.ECHILD),
		"ECHO":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"ECHOCTL":                       reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"ECHOE":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"ECHOK":                         reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"ECHOKE":                        reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"ECHONL":                        reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"ECHOPRT":                       reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"ECHRNG":                        reflect.ValueOf(syscall.ECHRNG),
		"ECOMM":                         reflect.ValueOf(syscall.ECOMM),
		"ECONNABORTED":                  reflect.ValueOf(syscall.ECONNABORTED),
		"ECONNREFUSED":                  reflect.ValueOf(syscall.ECONNREFUSED),
		"ECONNRESET":                    reflect.ValueOf(syscall.ECONNRESET),
		"EDEADLK":                       reflect.ValueOf(syscall.EDEADLK),
		"EDEADLOCK":                     reflect.ValueOf(syscall.EDEADLOCK),
		"EDESTADDRREQ":                  reflect.ValueOf(syscall.EDESTADDRREQ),
		"EDOM":                          reflect.ValueOf(syscall.EDOM),
		"EDQUOT":                        reflect.ValueOf(syscall.EDQUOT),
		"EEXIST":                        reflect.ValueOf(syscall.EEXIST),
		"EFAULT":                        reflect.ValueOf(syscall.EFAULT),
		"EFBIG":                         reflect.ValueOf(syscall.EFBIG),
		"EHOSTDOWN":                     reflect.ValueOf(syscall.EHOSTDOWN),
		"EHOSTUNREACH":                  reflect.ValueOf(syscall.EHOSTUNREACH),
		"EIDRM":                         reflect.ValueOf(syscall.EIDRM),
		"EILSEQ":                        reflect.ValueOf(syscall.EILSEQ),
		"EINPROGRESS":                   reflect.ValueOf(syscall.EINPROGRESS),
		"EINTR":                         reflect.ValueOf(syscall.EINTR),
		"EINVAL":                        reflect.ValueOf(syscall.EINVAL),
		"EIO":                           reflect.ValueOf(syscall.EIO),
		"EISCONN":                       reflect.ValueOf(syscall.EISCONN),
		"EISDIR":                        reflect.ValueOf(syscall.EISDIR),
		"EL2HLT":                        reflect.ValueOf(syscall.EL2HLT),
		"EL2NSYNC":                      reflect.ValueOf(syscall.EL2NSYNC),
		"EL3HLT":                        reflect.ValueOf(syscall.EL3HLT),
		"EL3RST":                        reflect.ValueOf(syscall.EL3RST),
		"ELIBACC":                       reflect.ValueOf(syscall.ELIBACC),
		"ELIBBAD":                       reflect.ValueOf(syscall.ELIBBAD),
		"ELIBEXEC":                      reflect.ValueOf(syscall.ELIBEXEC),
		"ELIBMAX":                       reflect.ValueOf(syscall.ELIBMAX),
		"ELIBSCN":                       reflect.ValueOf(syscall.ELIBSCN),
		"ELNRNG":                        reflect.ValueOf(syscall.ELNRNG),
		"ELOCKUNMAPPED":                 reflect.ValueOf(syscall.ELOCKUNMAPPED),
		"ELOOP":                         reflect.ValueOf(syscall.ELOOP),
		"EMFILE":                        reflect.ValueOf(syscall.EMFILE),
		"EMLINK":                        reflect.ValueOf(syscall.EMLINK),
		"EMPTY_SET":                     reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"EMSGSIZE":                      reflect.ValueOf(syscall.EMSGSIZE),
		"EMT_CPCOVF":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"EMULTIHOP":                     reflect.ValueOf(syscall.EMULTIHOP),
		"ENAMETOOLONG":                  reflect.ValueOf(syscall.ENAMETOOLONG),
		"ENETDOWN":                      reflect.ValueOf(syscall.ENETDOWN),
		"ENETRESET":                     reflect.ValueOf(syscall.ENETRESET),
		"ENETUNREACH":                   reflect.ValueOf(syscall.ENETUNREACH),
		"ENFILE":                        reflect.ValueOf(syscall.ENFILE),
		"ENOANO":                        reflect.ValueOf(syscall.ENOANO),
		"ENOBUFS":                       reflect.ValueOf(syscall.ENOBUFS),
		"ENOCSI":                        reflect.ValueOf(syscall.ENOCSI),
		"ENODATA":                       reflect.ValueOf(syscall.ENODATA),
		"ENODEV":                        reflect.ValueOf(syscall.ENODEV),
		"ENOENT":                        reflect.ValueOf(syscall.ENOENT),
		"ENOEXEC":                       reflect.ValueOf(syscall.ENOEXEC),
		"ENOLCK":                        reflect.ValueOf(syscall.ENOLCK),
		"ENOLINK":                       reflect.ValueOf(syscall.ENOLINK),
		"ENOMEM":                        reflect.ValueOf(syscall.ENOMEM),
		"ENOMSG":                        reflect.ValueOf(syscall.ENOMSG),
		"ENONET":                        reflect.ValueOf(syscall.ENONET),
		"ENOPKG":                        reflect.ValueOf(syscall.ENOPKG),
		"ENOPROTOOPT":                   reflect.ValueOf(syscall.ENOPROTOOPT),
		"ENOSPC":                        reflect.ValueOf(syscall.ENOSPC),
		"ENOSR":                         reflect.ValueOf(syscall.ENOSR),
		"ENOSTR":                        reflect.ValueOf(syscall.ENOSTR),
		"ENOSYS":                        reflect.ValueOf(syscall.ENOSYS),
		"ENOTACTIVE":                    reflect.ValueOf(syscall.ENOTACTIVE),
		"ENOTBLK":                       reflect.ValueOf(syscall.ENOTBLK),
		"ENOTCONN":                      reflect.ValueOf(syscall.ENOTCONN),
		"ENOTDIR":                       reflect.ValueOf(syscall.ENOTDIR),
		"ENOTEMPTY":                     reflect.ValueOf(syscall.ENOTEMPTY),
		"ENOTRECOVERABLE":               reflect.ValueOf(syscall.ENOTRECOVERABLE),
		"ENOTSOCK":                      reflect.ValueOf(syscall.ENOTSOCK),
		"ENOTSUP":                       reflect.ValueOf(syscall.ENOTSUP),
		"ENOTTY":                        reflect.ValueOf(syscall.ENOTTY),
		"ENOTUNIQ":                      reflect.ValueOf(syscall.ENOTUNIQ),
		"ENXIO":                         reflect.ValueOf(syscall.ENXIO),
		"EOPNOTSUPP":                    reflect.ValueOf(syscall.EOPNOTSUPP),
		"EOVERFLOW":                     reflect.ValueOf(syscall.EOVERFLOW),
		"EOWNERDEAD":                    reflect.ValueOf(syscall.EOWNERDEAD),
		"EPERM":                         reflect.ValueOf(syscall.EPERM),
		"EPFNOSUPPORT":                  reflect.ValueOf(syscall.EPFNOSUPPORT),
		"EPIPE":                         reflect.ValueOf(syscall.EPIPE),
		"EPROTO":                        reflect.ValueOf(syscall.EPROTO),
		"EPROTONOSUPPORT":               reflect.ValueOf(syscall.EPROTONOSUPPORT),
		"EPROTOTYPE":                    reflect.ValueOf(syscall.EPROTOTYPE),
		"EQUALITY_CHECK":                reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"ERANGE":                        reflect.ValueOf(syscall.ERANGE),
		"EREMCHG":                       reflect.ValueOf(syscall.EREMCHG),
		"EREMOTE":                       reflect.ValueOf(syscall.EREMOTE),
		"ERESTART":                      reflect.ValueOf(syscall.ERESTART),
		"EROFS":                         reflect.ValueOf(syscall.EROFS),
		"ESHUTDOWN":                     reflect.ValueOf(syscall.ESHUTDOWN),
		"ESOCKTNOSUPPORT":               reflect.ValueOf(syscall.ESOCKTNOSUPPORT),
		"ESPIPE":                        reflect.ValueOf(syscall.ESPIPE),
		"ESRCH":                         reflect.ValueOf(syscall.ESRCH),
		"ESRMNT":                        reflect.ValueOf(syscall.ESRMNT),
		"ESTALE":                        reflect.ValueOf(syscall.ESTALE),
		"ESTRPIPE":                      reflect.ValueOf(syscall.ESTRPIPE),
		"ETIME":                         reflect.ValueOf(syscall.ETIME),
		"ETIMEDOUT":                     reflect.ValueOf(syscall.ETIMEDOUT),
		"ETOOMANYREFS":                  reflect.ValueOf(syscall.ETOOMANYREFS),
		"ETXTBSY":                       reflect.ValueOf(syscall.ETXTBSY),
		"EUNATCH":                       reflect.ValueOf(syscall.EUNATCH),
		"EUSERS":                        reflect.ValueOf(syscall.EUSERS),
		"EWOULDBLOCK":                   reflect.ValueOf(syscall.EWOULDBLOCK),
		"EXDEV":                         reflect.ValueOf(syscall.EXDEV),
		"EXFULL":                        reflect.ValueOf(syscall.EXFULL),
		"EXTA":                          reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"EXTB":                          reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"Environ":                       reflect.ValueOf(syscall.Environ),
		"FD_CLOEXEC":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FD_NFDBITS":                    reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"FD_SETSIZE":                    reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"FLUSHALL":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FLUSHDATA":                     reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"FLUSHO":                        reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"F_ALLOCSP":                     reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"F_ALLOCSP64":                   reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"F_BADFD":                       reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"F_BLKSIZE":                     reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"F_BLOCKS":                      reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"F_CHKFL":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"F_COMPAT":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"F_DUP2FD":                      reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"F_DUP2FD_CLOEXEC":              reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"F_DUPFD":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"F_DUPFD_CLOEXEC":               reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"F_FREESP":                      reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"F_FREESP64":                    reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"F_GETFD":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_GETFL":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"F_GETLK":                       reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"F_GETLK64":                     reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"F_GETOWN":                      reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"F_GETXFL":                      reflect.ValueOf(constant.MakeFromLiteral("45", token.INT, 0)),
		"F_HASREMOTELOCKS":              reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"F_ISSTREAM":                    reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"F_MANDDNY":                     reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"F_MDACC":                       reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"F_NODNY":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"F_NPRIV":                       reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"F_PRIV":                        reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"F_QUOTACTL":                    reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"F_RDACC":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_RDDNY":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_RDLCK":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_REVOKE":                      reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"F_RMACC":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"F_RMDNY":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"F_RWACC":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"F_RWDNY":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"F_SETFD":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"F_SETFL":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"F_SETLK":                       reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"F_SETLK64":                     reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"F_SETLK64_NBMAND":              reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"F_SETLKW":                      reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"F_SETLKW64":                    reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"F_SETLK_NBMAND":                reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"F_SETOWN":                      reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"F_SHARE":                       reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"F_SHARE_NBMAND":                reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"F_UNLCK":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"F_UNLKSYS":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"F_UNSHARE":                     reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"F_WRACC":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"F_WRDNY":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"F_WRLCK":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"Fchdir":                        reflect.ValueOf(syscall.Fchdir),
		"Fchmod":                        reflect.ValueOf(syscall.Fchmod),
		"Fchown":                        reflect.ValueOf(syscall.Fchown),
		"FcntlFlock":                    reflect.ValueOf(syscall.FcntlFlock),
		"Flock":                         reflect.ValueOf(syscall.Flock),
		"ForkLock":                      reflect.ValueOf(&syscall.ForkLock).Elem(),
		"Fpathconf":                     reflect.ValueOf(syscall.Fpathconf),
		"Fstat":                         reflect.ValueOf(syscall.Fstat),
		"Fsync":                         reflect.ValueOf(syscall.Fsync),
		"Ftruncate":                     reflect.ValueOf(syscall.Ftruncate),
		"Getcwd":                        reflect.ValueOf(syscall.Getcwd),
		"Getdents":                      reflect.ValueOf(syscall.Getdents),
		"Getegid":                       reflect.ValueOf(syscall.Getegid),
		"Getenv":                        reflect.ValueOf(syscall.Getenv),
		"Geteuid":                       reflect.ValueOf(syscall.Geteuid),
		"Getexecname":                   reflect.ValueOf(syscall.Getexecname),
		"Getgid":                        reflect.ValueOf(syscall.Getgid),
		"Getgroups":                     reflect.ValueOf(syscall.Getgroups),
		"Gethostname":                   reflect.ValueOf(syscall.Gethostname),
		"Getpagesize":                   reflect.ValueOf(syscall.Getpagesize),
		"Getpeername":                   reflect.ValueOf(syscall.Getpeername),
		"Getpid":                        reflect.ValueOf(syscall.Getpid),
		"Getppid":                       reflect.ValueOf(syscall.Getppid),
		"Getpriority":                   reflect.ValueOf(syscall.Getpriority),
		"Getrlimit":                     reflect.ValueOf(syscall.Getrlimit),
		"Getrusage":                     reflect.ValueOf(syscall.Getrusage),
		"Getsockname":                   reflect.ValueOf(syscall.Getsockname),
		"GetsockoptInt":                 reflect.ValueOf(syscall.GetsockoptInt),
		"Gettimeofday":                  reflect.ValueOf(syscall.Gettimeofday),
		"Getuid":                        reflect.ValueOf(syscall.Getuid),
		"Getwd":                         reflect.ValueOf(syscall.Getwd),
		"HUPCL":                         reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"ICANON":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ICRNL":                         reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IEXTEN":                        reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"IFF_ADDRCONF":                  reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"IFF_ALLMULTI":                  reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"IFF_ANYCAST":                   reflect.ValueOf(constant.MakeFromLiteral("4194304", token.INT, 0)),
		"IFF_BROADCAST":                 reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IFF_CANTCHANGE":                reflect.ValueOf(constant.MakeFromLiteral("8736013826906", token.INT, 0)),
		"IFF_COS_ENABLED":               reflect.ValueOf(constant.MakeFromLiteral("8589934592", token.INT, 0)),
		"IFF_DEBUG":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IFF_DEPRECATED":                reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"IFF_DHCPRUNNING":               reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"IFF_DUPLICATE":                 reflect.ValueOf(constant.MakeFromLiteral("274877906944", token.INT, 0)),
		"IFF_FAILED":                    reflect.ValueOf(constant.MakeFromLiteral("268435456", token.INT, 0)),
		"IFF_FIXEDMTU":                  reflect.ValueOf(constant.MakeFromLiteral("68719476736", token.INT, 0)),
		"IFF_INACTIVE":                  reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"IFF_INTELLIGENT":               reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"IFF_IPMP":                      reflect.ValueOf(constant.MakeFromLiteral("549755813888", token.INT, 0)),
		"IFF_IPMP_CANTCHANGE":           reflect.ValueOf(constant.MakeFromLiteral("268435456", token.INT, 0)),
		"IFF_IPMP_INVALID":              reflect.ValueOf(constant.MakeFromLiteral("8256487552", token.INT, 0)),
		"IFF_IPV4":                      reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"IFF_IPV6":                      reflect.ValueOf(constant.MakeFromLiteral("33554432", token.INT, 0)),
		"IFF_L3PROTECT":                 reflect.ValueOf(constant.MakeFromLiteral("4398046511104", token.INT, 0)),
		"IFF_LOOPBACK":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IFF_MULTICAST":                 reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"IFF_MULTI_BCAST":               reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"IFF_NOACCEPT":                  reflect.ValueOf(constant.MakeFromLiteral("67108864", token.INT, 0)),
		"IFF_NOARP":                     reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IFF_NOFAILOVER":                reflect.ValueOf(constant.MakeFromLiteral("134217728", token.INT, 0)),
		"IFF_NOLINKLOCAL":               reflect.ValueOf(constant.MakeFromLiteral("2199023255552", token.INT, 0)),
		"IFF_NOLOCAL":                   reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"IFF_NONUD":                     reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"IFF_NORTEXCH":                  reflect.ValueOf(constant.MakeFromLiteral("8388608", token.INT, 0)),
		"IFF_NOTRAILERS":                reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IFF_NOXMIT":                    reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"IFF_OFFLINE":                   reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"IFF_POINTOPOINT":               reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFF_PREFERRED":                 reflect.ValueOf(constant.MakeFromLiteral("17179869184", token.INT, 0)),
		"IFF_PRIVATE":                   reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"IFF_PROMISC":                   reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IFF_ROUTER":                    reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"IFF_RUNNING":                   reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IFF_STANDBY":                   reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"IFF_TEMPORARY":                 reflect.ValueOf(constant.MakeFromLiteral("34359738368", token.INT, 0)),
		"IFF_UNNUMBERED":                reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"IFF_UP":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFF_VIRTUAL":                   reflect.ValueOf(constant.MakeFromLiteral("137438953472", token.INT, 0)),
		"IFF_VRRP":                      reflect.ValueOf(constant.MakeFromLiteral("1099511627776", token.INT, 0)),
		"IFF_XRESOLV":                   reflect.ValueOf(constant.MakeFromLiteral("4294967296", token.INT, 0)),
		"IFNAMSIZ":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFT_1822":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IFT_6TO4":                      reflect.ValueOf(constant.MakeFromLiteral("202", token.INT, 0)),
		"IFT_AAL5":                      reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"IFT_ARCNET":                    reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"IFT_ARCNETPLUS":                reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"IFT_ATM":                       reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"IFT_CEPT":                      reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"IFT_DS3":                       reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"IFT_EON":                       reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"IFT_ETHER":                     reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IFT_FDDI":                      reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"IFT_FRELAY":                    reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IFT_FRELAYDCE":                 reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"IFT_HDH1822":                   reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IFT_HIPPI":                     reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"IFT_HSSI":                      reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"IFT_HY":                        reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"IFT_IB":                        reflect.ValueOf(constant.MakeFromLiteral("199", token.INT, 0)),
		"IFT_IPV4":                      reflect.ValueOf(constant.MakeFromLiteral("200", token.INT, 0)),
		"IFT_IPV6":                      reflect.ValueOf(constant.MakeFromLiteral("201", token.INT, 0)),
		"IFT_ISDNBASIC":                 reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IFT_ISDNPRIMARY":               reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"IFT_ISO88022LLC":               reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"IFT_ISO88023":                  reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"IFT_ISO88024":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IFT_ISO88025":                  reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IFT_ISO88026":                  reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IFT_LAPB":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFT_LOCALTALK":                 reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"IFT_LOOP":                      reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IFT_MIOX25":                    reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"IFT_MODEM":                     reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"IFT_NSIP":                      reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"IFT_OTHER":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFT_P10":                       reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IFT_P80":                       reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IFT_PARA":                      reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"IFT_PPP":                       reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"IFT_PROPMUX":                   reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"IFT_PROPVIRTUAL":               reflect.ValueOf(constant.MakeFromLiteral("53", token.INT, 0)),
		"IFT_PTPSERIAL":                 reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IFT_RS232":                     reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"IFT_SDLC":                      reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IFT_SIP":                       reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"IFT_SLIP":                      reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"IFT_SMDSDXI":                   reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"IFT_SMDSICIP":                  reflect.ValueOf(constant.MakeFromLiteral("52", token.INT, 0)),
		"IFT_SONET":                     reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"IFT_SONETPATH":                 reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"IFT_SONETVT":                   reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"IFT_STARLAN":                   reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IFT_T1":                        reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"IFT_ULTRA":                     reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"IFT_V35":                       reflect.ValueOf(constant.MakeFromLiteral("45", token.INT, 0)),
		"IFT_X25":                       reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"IFT_X25DDN":                    reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IFT_X25PLE":                    reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"IFT_XETHER":                    reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"IGNBRK":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IGNCR":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IGNPAR":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IMAXBEL":                       reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"INLCR":                         reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"INPCK":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IN_AUTOCONF_MASK":              reflect.ValueOf(constant.MakeFromLiteral("4294901760", token.INT, 0)),
		"IN_AUTOCONF_NET":               reflect.ValueOf(constant.MakeFromLiteral("2851995648", token.INT, 0)),
		"IN_CLASSA_HOST":                reflect.ValueOf(constant.MakeFromLiteral("16777215", token.INT, 0)),
		"IN_CLASSA_MAX":                 reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IN_CLASSA_NET":                 reflect.ValueOf(constant.MakeFromLiteral("4278190080", token.INT, 0)),
		"IN_CLASSA_NSHIFT":              reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IN_CLASSB_HOST":                reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"IN_CLASSB_MAX":                 reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"IN_CLASSB_NET":                 reflect.ValueOf(constant.MakeFromLiteral("4294901760", token.INT, 0)),
		"IN_CLASSB_NSHIFT":              reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IN_CLASSC_HOST":                reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"IN_CLASSC_NET":                 reflect.ValueOf(constant.MakeFromLiteral("4294967040", token.INT, 0)),
		"IN_CLASSC_NSHIFT":              reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IN_CLASSD_HOST":                reflect.ValueOf(constant.MakeFromLiteral("268435455", token.INT, 0)),
		"IN_CLASSD_NET":                 reflect.ValueOf(constant.MakeFromLiteral("4026531840", token.INT, 0)),
		"IN_CLASSD_NSHIFT":              reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"IN_CLASSE_NET":                 reflect.ValueOf(constant.MakeFromLiteral("4294967295", token.INT, 0)),
		"IN_LOOPBACKNET":                reflect.ValueOf(constant.MakeFromLiteral("127", token.INT, 0)),
		"IN_PRIVATE12_MASK":             reflect.ValueOf(constant.MakeFromLiteral("4293918720", token.INT, 0)),
		"IN_PRIVATE12_NET":              reflect.ValueOf(constant.MakeFromLiteral("2886729728", token.INT, 0)),
		"IN_PRIVATE16_MASK":             reflect.ValueOf(constant.MakeFromLiteral("4294901760", token.INT, 0)),
		"IN_PRIVATE16_NET":              reflect.ValueOf(constant.MakeFromLiteral("3232235520", token.INT, 0)),
		"IN_PRIVATE8_MASK":              reflect.ValueOf(constant.MakeFromLiteral("4278190080", token.INT, 0)),
		"IN_PRIVATE8_NET":               reflect.ValueOf(constant.MakeFromLiteral("167772160", token.INT, 0)),
		"IPPROTO_AH":                    reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"IPPROTO_DSTOPTS":               reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"IPPROTO_EGP":                   reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IPPROTO_ENCAP":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IPPROTO_EON":                   reflect.ValueOf(constant.MakeFromLiteral("80", token.INT, 0)),
		"IPPROTO_ESP":                   reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"IPPROTO_FRAGMENT":              reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"IPPROTO_GGP":                   reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IPPROTO_HELLO":                 reflect.ValueOf(constant.MakeFromLiteral("63", token.INT, 0)),
		"IPPROTO_HOPOPTS":               reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPPROTO_ICMP":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPPROTO_ICMPV6":                reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"IPPROTO_IDP":                   reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IPPROTO_IGMP":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IPPROTO_IP":                    reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPPROTO_IPV6":                  reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"IPPROTO_MAX":                   reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IPPROTO_ND":                    reflect.ValueOf(constant.MakeFromLiteral("77", token.INT, 0)),
		"IPPROTO_NONE":                  reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"IPPROTO_OSPF":                  reflect.ValueOf(constant.MakeFromLiteral("89", token.INT, 0)),
		"IPPROTO_PIM":                   reflect.ValueOf(constant.MakeFromLiteral("103", token.INT, 0)),
		"IPPROTO_PUP":                   reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IPPROTO_RAW":                   reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"IPPROTO_ROUTING":               reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"IPPROTO_RSVP":                  reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"IPPROTO_SCTP":                  reflect.ValueOf(constant.MakeFromLiteral("132", token.INT, 0)),
		"IPPROTO_TCP":                   reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IPPROTO_UDP":                   reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IPV6_ADD_MEMBERSHIP":           reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IPV6_BOUND_IF":                 reflect.ValueOf(constant.MakeFromLiteral("65", token.INT, 0)),
		"IPV6_CHECKSUM":                 reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IPV6_DONTFRAG":                 reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"IPV6_DROP_MEMBERSHIP":          reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IPV6_DSTOPTS":                  reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"IPV6_FLOWINFO_FLOWLABEL":       reflect.ValueOf(constant.MakeFromLiteral("4294905600", token.INT, 0)),
		"IPV6_FLOWINFO_TCLASS":          reflect.ValueOf(constant.MakeFromLiteral("61455", token.INT, 0)),
		"IPV6_HOPLIMIT":                 reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IPV6_HOPOPTS":                  reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"IPV6_JOIN_GROUP":               reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IPV6_LEAVE_GROUP":              reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IPV6_MULTICAST_HOPS":           reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"IPV6_MULTICAST_IF":             reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IPV6_MULTICAST_LOOP":           reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IPV6_NEXTHOP":                  reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IPV6_PAD1_OPT":                 reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPV6_PATHMTU":                  reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"IPV6_PKTINFO":                  reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IPV6_PREFER_SRC_CGA":           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IPV6_PREFER_SRC_CGADEFAULT":    reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IPV6_PREFER_SRC_CGAMASK":       reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"IPV6_PREFER_SRC_COA":           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IPV6_PREFER_SRC_DEFAULT":       reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"IPV6_PREFER_SRC_HOME":          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPV6_PREFER_SRC_MASK":          reflect.ValueOf(constant.MakeFromLiteral("63", token.INT, 0)),
		"IPV6_PREFER_SRC_MIPDEFAULT":    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPV6_PREFER_SRC_MIPMASK":       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IPV6_PREFER_SRC_NONCGA":        reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IPV6_PREFER_SRC_PUBLIC":        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IPV6_PREFER_SRC_TMP":           reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IPV6_PREFER_SRC_TMPDEFAULT":    reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IPV6_PREFER_SRC_TMPMASK":       reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IPV6_RECVDSTOPTS":              reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"IPV6_RECVHOPLIMIT":             reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"IPV6_RECVHOPOPTS":              reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IPV6_RECVPATHMTU":              reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"IPV6_RECVPKTINFO":              reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"IPV6_RECVRTHDR":                reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IPV6_RECVRTHDRDSTOPTS":         reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"IPV6_RECVTCLASS":               reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"IPV6_RTHDR":                    reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IPV6_RTHDRDSTOPTS":             reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IPV6_RTHDR_TYPE_0":             reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPV6_SEC_OPT":                  reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"IPV6_SRC_PREFERENCES":          reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"IPV6_TCLASS":                   reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"IPV6_UNICAST_HOPS":             reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"IPV6_UNSPEC_SRC":               reflect.ValueOf(constant.MakeFromLiteral("66", token.INT, 0)),
		"IPV6_USE_MIN_MTU":              reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IPV6_V6ONLY":                   reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"IP_ADD_MEMBERSHIP":             reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"IP_ADD_SOURCE_MEMBERSHIP":      reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"IP_BLOCK_SOURCE":               reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"IP_BOUND_IF":                   reflect.ValueOf(constant.MakeFromLiteral("65", token.INT, 0)),
		"IP_BROADCAST":                  reflect.ValueOf(constant.MakeFromLiteral("262", token.INT, 0)),
		"IP_BROADCAST_TTL":              reflect.ValueOf(constant.MakeFromLiteral("67", token.INT, 0)),
		"IP_DEFAULT_MULTICAST_LOOP":     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_DEFAULT_MULTICAST_TTL":      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_DF":                         reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"IP_DHCPINIT_IF":                reflect.ValueOf(constant.MakeFromLiteral("69", token.INT, 0)),
		"IP_DONTFRAG":                   reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"IP_DONTROUTE":                  reflect.ValueOf(constant.MakeFromLiteral("261", token.INT, 0)),
		"IP_DROP_MEMBERSHIP":            reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IP_DROP_SOURCE_MEMBERSHIP":     reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IP_HDRINCL":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IP_MAXPACKET":                  reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"IP_MF":                         reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"IP_MSS":                        reflect.ValueOf(constant.MakeFromLiteral("576", token.INT, 0)),
		"IP_MULTICAST_IF":               reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IP_MULTICAST_LOOP":             reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"IP_MULTICAST_TTL":              reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IP_NEXTHOP":                    reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"IP_OPTIONS":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_PKTINFO":                    reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"IP_RECVDSTADDR":                reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"IP_RECVIF":                     reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IP_RECVOPTS":                   reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"IP_RECVPKTINFO":                reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"IP_RECVRETOPTS":                reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IP_RECVSLLA":                   reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IP_RECVTTL":                    reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IP_RETOPTS":                    reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IP_REUSEADDR":                  reflect.ValueOf(constant.MakeFromLiteral("260", token.INT, 0)),
		"IP_SEC_OPT":                    reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"IP_TOS":                        reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IP_TTL":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IP_UNBLOCK_SOURCE":             reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IP_UNSPEC_SRC":                 reflect.ValueOf(constant.MakeFromLiteral("66", token.INT, 0)),
		"ISIG":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"ISTRIP":                        reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IXANY":                         reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"IXOFF":                         reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"IXON":                          reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"ImplementsGetwd":               reflect.ValueOf(syscall.ImplementsGetwd),
		"LOCK_EX":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"LOCK_NB":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"LOCK_SH":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"LOCK_UN":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"Lchown":                        reflect.ValueOf(syscall.Lchown),
		"Link":                          reflect.ValueOf(syscall.Link),
		"Listen":                        reflect.ValueOf(syscall.Listen),
		"Lstat":                         reflect.ValueOf(syscall.Lstat),
		"MADV_ACCESS_DEFAULT":           reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"MADV_ACCESS_LWP":               reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"MADV_ACCESS_MANY":              reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"MADV_DONTNEED":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MADV_FREE":                     reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"MADV_NORMAL":                   reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MADV_RANDOM":                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MADV_SEQUENTIAL":               reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MADV_WILLNEED":                 reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"MAP_32BIT":                     reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"MAP_ALIGN":                     reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"MAP_ANON":                      reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"MAP_ANONYMOUS":                 reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"MAP_FILE":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MAP_FIXED":                     reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"MAP_INITDATA":                  reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"MAP_NORESERVE":                 reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"MAP_PRIVATE":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MAP_RENAME":                    reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"MAP_SHARED":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MAP_TEXT":                      reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"MAP_TYPE":                      reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"MCL_CURRENT":                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MCL_FUTURE":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MSG_CTRUNC":                    reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"MSG_DONTROUTE":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MSG_DONTWAIT":                  reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"MSG_DUPCTRL":                   reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"MSG_EOR":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"MSG_MAXIOVLEN":                 reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"MSG_NOTIFICATION":              reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"MSG_OOB":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MSG_PEEK":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MSG_TRUNC":                     reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"MSG_WAITALL":                   reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"MSG_XPG4_2":                    reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"MS_ASYNC":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MS_INVALIDATE":                 reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MS_OLDSYNC":                    reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MS_SYNC":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"M_FLUSH":                       reflect.ValueOf(constant.MakeFromLiteral("134", token.INT, 0)),
		"Mkdir":                         reflect.ValueOf(syscall.Mkdir),
		"Mknod":                         reflect.ValueOf(syscall.Mknod),
		"Mmap":                          reflect.ValueOf(syscall.Mmap),
		"Munmap":                        reflect.ValueOf(syscall.Munmap),
		"NOFLSH":                        reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"Nanosleep":                     reflect.ValueOf(syscall.Nanosleep),
		"NsecToTimespec":                reflect.ValueOf(syscall.NsecToTimespec),
		"NsecToTimeval":                 reflect.ValueOf(syscall.NsecToTimeval),
		"OCRNL":                         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"OFDEL":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"OFILL":                         reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"ONLCR":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"ONLRET":                        reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"ONOCR":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"OPENFAIL":                      reflect.ValueOf(constant.MakeFromLiteral("-1", token.INT, 0)),
		"OPOST":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"O_ACCMODE":                     reflect.ValueOf(constant.MakeFromLiteral("6291459", token.INT, 0)),
		"O_APPEND":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"O_CLOEXEC":                     reflect.ValueOf(constant.MakeFromLiteral("8388608", token.INT, 0)),
		"O_CREAT":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"O_DIRECTORY":                   reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"O_DSYNC":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"O_EXCL":                        reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"O_EXEC":                        reflect.ValueOf(constant.MakeFromLiteral("4194304", token.INT, 0)),
		"O_LARGEFILE":                   reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"O_NDELAY":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"O_NOCTTY":                      reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"O_NOFOLLOW":                    reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"O_NOLINKS":                     reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"O_NONBLOCK":                    reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"O_RDONLY":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"O_RDWR":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"O_RSYNC":                       reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"O_SEARCH":                      reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"O_SIOCGIFCONF":                 reflect.ValueOf(constant.MakeFromLiteral("-1073190636", token.INT, 0)),
		"O_SIOCGLIFCONF":                reflect.ValueOf(constant.MakeFromLiteral("-1072666248", token.INT, 0)),
		"O_SYNC":                        reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"O_TRUNC":                       reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"O_WRONLY":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"O_XATTR":                       reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"Open":                          reflect.ValueOf(syscall.Open),
		"PARENB":                        reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"PAREXT":                        reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"PARMRK":                        reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PARODD":                        reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"PENDIN":                        reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"PRIO_PGRP":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PRIO_PROCESS":                  reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PRIO_USER":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PROT_EXEC":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PROT_NONE":                     reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PROT_READ":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PROT_WRITE":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ParseDirent":                   reflect.ValueOf(syscall.ParseDirent),
		"ParseSocketControlMessage":     reflect.ValueOf(syscall.ParseSocketControlMessage),
		"ParseUnixRights":               reflect.ValueOf(syscall.ParseUnixRights),
		"PathMax":                       reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"Pathconf":                      reflect.ValueOf(syscall.Pathconf),
		"Pipe":                          reflect.ValueOf(syscall.Pipe),
		"Pipe2":                         reflect.ValueOf(syscall.Pipe2),
		"Pread":                         reflect.ValueOf(syscall.Pread),
		"Pwrite":                        reflect.ValueOf(syscall.Pwrite),
		"RLIMIT_AS":                     reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"RLIMIT_CORE":                   reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RLIMIT_CPU":                    reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RLIMIT_DATA":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RLIMIT_FSIZE":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RLIMIT_NOFILE":                 reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"RLIMIT_STACK":                  reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RLIM_INFINITY":                 reflect.ValueOf(constant.MakeFromLiteral("-3", token.INT, 0)),
		"RTAX_AUTHOR":                   reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"RTAX_BRD":                      reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"RTAX_DST":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RTAX_GATEWAY":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTAX_GENMASK":                  reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RTAX_IFA":                      reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"RTAX_IFP":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTAX_MAX":                      reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"RTAX_NETMASK":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTAX_SRC":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTA_AUTHOR":                    reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RTA_BRD":                       reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"RTA_DST":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTA_GATEWAY":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTA_GENMASK":                   reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTA_IFA":                       reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"RTA_IFP":                       reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTA_NETMASK":                   reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTA_NUMBITS":                   reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"RTA_SRC":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"RTF_BLACKHOLE":                 reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"RTF_CLONING":                   reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"RTF_DONE":                      reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RTF_DYNAMIC":                   reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTF_GATEWAY":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTF_HOST":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTF_INDIRECT":                  reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"RTF_KERNEL":                    reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"RTF_LLINFO":                    reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"RTF_MASK":                      reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"RTF_MODIFIED":                  reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"RTF_MULTIRT":                   reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"RTF_PRIVATE":                   reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"RTF_PROTO1":                    reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"RTF_PROTO2":                    reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"RTF_REJECT":                    reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTF_SETSRC":                    reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"RTF_STATIC":                    reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"RTF_UP":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTF_XRESOLVE":                  reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"RTF_ZONE":                      reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"RTM_ADD":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTM_CHANGE":                    reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RTM_CHGADDR":                   reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"RTM_DELADDR":                   reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"RTM_DELETE":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTM_FREEADDR":                  reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTM_GET":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTM_IFINFO":                    reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"RTM_LOCK":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTM_LOSING":                    reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"RTM_MISS":                      reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"RTM_NEWADDR":                   reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"RTM_OLDADD":                    reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"RTM_OLDDEL":                    reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"RTM_REDIRECT":                  reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"RTM_RESOLVE":                   reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"RTM_VERSION":                   reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RTV_EXPIRE":                    reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTV_HOPCOUNT":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTV_MTU":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTV_RPIPE":                     reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTV_RTT":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RTV_RTTVAR":                    reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"RTV_SPIPE":                     reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTV_SSTHRESH":                  reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"RT_AWARE":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RUSAGE_CHILDREN":               reflect.ValueOf(constant.MakeFromLiteral("-1", token.INT, 0)),
		"RUSAGE_SELF":                   reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"Read":                          reflect.ValueOf(syscall.Read),
		"ReadDirent":                    reflect.ValueOf(syscall.ReadDirent),
		"Readlink":                      reflect.ValueOf(syscall.Readlink),
		"Recvfrom":                      reflect.ValueOf(syscall.Recvfrom),
		"Recvmsg":                       reflect.ValueOf(syscall.Recvmsg),
		"Rename":                        reflect.ValueOf(syscall.Rename),
		"Rmdir":                         reflect.ValueOf(syscall.Rmdir),
		"SCM_RIGHTS":                    reflect.ValueOf(constant.MakeFromLiteral("4112", token.INT, 0)),
		"SCM_TIMESTAMP":                 reflect.ValueOf(constant.MakeFromLiteral("4115", token.INT, 0)),
		"SCM_UCRED":                     reflect.ValueOf(constant.MakeFromLiteral("4114", token.INT, 0)),
		"SHUT_RD":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"SHUT_RDWR":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SHUT_WR":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SIG2STR_MAX":                   reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SIGABRT":                       reflect.ValueOf(syscall.SIGABRT),
		"SIGALRM":                       reflect.ValueOf(syscall.SIGALRM),
		"SIGBUS":                        reflect.ValueOf(syscall.SIGBUS),
		"SIGCANCEL":                     reflect.ValueOf(syscall.SIGCANCEL),
		"SIGCHLD":                       reflect.ValueOf(syscall.SIGCHLD),
		"SIGCLD":                        reflect.ValueOf(syscall.SIGCLD),
		"SIGCONT":                       reflect.ValueOf(syscall.SIGCONT),
		"SIGEMT":                        reflect.ValueOf(syscall.SIGEMT),
		"SIGFPE":                        reflect.ValueOf(syscall.SIGFPE),
		"SIGFREEZE":                     reflect.ValueOf(syscall.SIGFREEZE),
		"SIGHUP":                        reflect.ValueOf(syscall.SIGHUP),
		"SIGILL":                        reflect.ValueOf(syscall.SIGILL),
		"SIGINT":                        reflect.ValueOf(syscall.SIGINT),
		"SIGIO":                         reflect.ValueOf(syscall.SIGIO),
		"SIGIOT":                        reflect.ValueOf(syscall.SIGIOT),
		"SIGJVM1":                       reflect.ValueOf(syscall.SIGJVM1),
		"SIGJVM2":                       reflect.ValueOf(syscall.SIGJVM2),
		"SIGKILL":                       reflect.ValueOf(syscall.SIGKILL),
		"SIGLOST":                       reflect.ValueOf(syscall.SIGLOST),
		"SIGLWP":                        reflect.ValueOf(syscall.SIGLWP),
		"SIGPIPE":                       reflect.ValueOf(syscall.SIGPIPE),
		"SIGPOLL":                       reflect.ValueOf(syscall.SIGPOLL),
		"SIGPROF":                       reflect.ValueOf(syscall.SIGPROF),
		"SIGPWR":                        reflect.ValueOf(syscall.SIGPWR),
		"SIGQUIT":                       reflect.ValueOf(syscall.SIGQUIT),
		"SIGSEGV":                       reflect.ValueOf(syscall.SIGSEGV),
		"SIGSTOP":                       reflect.ValueOf(syscall.SIGSTOP),
		"SIGSYS":                        reflect.ValueOf(syscall.SIGSYS),
		"SIGTERM":                       reflect.ValueOf(syscall.SIGTERM),
		"SIGTHAW":                       reflect.ValueOf(syscall.SIGTHAW),
		"SIGTRAP":                       reflect.ValueOf(syscall.SIGTRAP),
		"SIGTSTP":                       reflect.ValueOf(syscall.SIGTSTP),
		"SIGTTIN":                       reflect.ValueOf(syscall.SIGTTIN),
		"SIGTTOU":                       reflect.ValueOf(syscall.SIGTTOU),
		"SIGURG":                        reflect.ValueOf(syscall.SIGURG),
		"SIGUSR1":                       reflect.ValueOf(syscall.SIGUSR1),
		"SIGUSR2":                       reflect.ValueOf(syscall.SIGUSR2),
		"SIGVTALRM":                     reflect.ValueOf(syscall.SIGVTALRM),
		"SIGWAITING":                    reflect.ValueOf(syscall.SIGWAITING),
		"SIGWINCH":                      reflect.ValueOf(syscall.SIGWINCH),
		"SIGXCPU":                       reflect.ValueOf(syscall.SIGXCPU),
		"SIGXFSZ":                       reflect.ValueOf(syscall.SIGXFSZ),
		"SIGXRES":                       reflect.ValueOf(syscall.SIGXRES),
		"SIOCADDMULTI":                  reflect.ValueOf(constant.MakeFromLiteral("-2145359567", token.INT, 0)),
		"SIOCADDRT":                     reflect.ValueOf(constant.MakeFromLiteral("-2144308726", token.INT, 0)),
		"SIOCATMARK":                    reflect.ValueOf(constant.MakeFromLiteral("1074033415", token.INT, 0)),
		"SIOCDARP":                      reflect.ValueOf(constant.MakeFromLiteral("-2145097440", token.INT, 0)),
		"SIOCDELMULTI":                  reflect.ValueOf(constant.MakeFromLiteral("-2145359566", token.INT, 0)),
		"SIOCDELRT":                     reflect.ValueOf(constant.MakeFromLiteral("-2144308725", token.INT, 0)),
		"SIOCDIPSECONFIG":               reflect.ValueOf(constant.MakeFromLiteral("-2147194473", token.INT, 0)),
		"SIOCDXARP":                     reflect.ValueOf(constant.MakeFromLiteral("-2147456600", token.INT, 0)),
		"SIOCFIPSECONFIG":               reflect.ValueOf(constant.MakeFromLiteral("-2147194475", token.INT, 0)),
		"SIOCGARP":                      reflect.ValueOf(constant.MakeFromLiteral("-1071355617", token.INT, 0)),
		"SIOCGDSTINFO":                  reflect.ValueOf(constant.MakeFromLiteral("-1073714780", token.INT, 0)),
		"SIOCGENADDR":                   reflect.ValueOf(constant.MakeFromLiteral("-1071617707", token.INT, 0)),
		"SIOCGENPSTATS":                 reflect.ValueOf(constant.MakeFromLiteral("-1071617735", token.INT, 0)),
		"SIOCGETLSGCNT":                 reflect.ValueOf(constant.MakeFromLiteral("-1072664043", token.INT, 0)),
		"SIOCGETNAME":                   reflect.ValueOf(constant.MakeFromLiteral("1074819892", token.INT, 0)),
		"SIOCGETPEER":                   reflect.ValueOf(constant.MakeFromLiteral("1074819893", token.INT, 0)),
		"SIOCGETPROP":                   reflect.ValueOf(constant.MakeFromLiteral("-1073712964", token.INT, 0)),
		"SIOCGETSGCNT":                  reflect.ValueOf(constant.MakeFromLiteral("-1072401899", token.INT, 0)),
		"SIOCGETSYNC":                   reflect.ValueOf(constant.MakeFromLiteral("-1071617747", token.INT, 0)),
		"SIOCGETVIFCNT":                 reflect.ValueOf(constant.MakeFromLiteral("-1072401900", token.INT, 0)),
		"SIOCGHIWAT":                    reflect.ValueOf(constant.MakeFromLiteral("1074033409", token.INT, 0)),
		"SIOCGIFADDR":                   reflect.ValueOf(constant.MakeFromLiteral("-1071617779", token.INT, 0)),
		"SIOCGIFBRDADDR":                reflect.ValueOf(constant.MakeFromLiteral("-1071617769", token.INT, 0)),
		"SIOCGIFCONF":                   reflect.ValueOf(constant.MakeFromLiteral("-1073190564", token.INT, 0)),
		"SIOCGIFDSTADDR":                reflect.ValueOf(constant.MakeFromLiteral("-1071617777", token.INT, 0)),
		"SIOCGIFFLAGS":                  reflect.ValueOf(constant.MakeFromLiteral("-1071617775", token.INT, 0)),
		"SIOCGIFHWADDR":                 reflect.ValueOf(constant.MakeFromLiteral("-1071617607", token.INT, 0)),
		"SIOCGIFINDEX":                  reflect.ValueOf(constant.MakeFromLiteral("-1071617702", token.INT, 0)),
		"SIOCGIFMEM":                    reflect.ValueOf(constant.MakeFromLiteral("-1071617773", token.INT, 0)),
		"SIOCGIFMETRIC":                 reflect.ValueOf(constant.MakeFromLiteral("-1071617765", token.INT, 0)),
		"SIOCGIFMTU":                    reflect.ValueOf(constant.MakeFromLiteral("-1071617770", token.INT, 0)),
		"SIOCGIFMUXID":                  reflect.ValueOf(constant.MakeFromLiteral("-1071617704", token.INT, 0)),
		"SIOCGIFNETMASK":                reflect.ValueOf(constant.MakeFromLiteral("-1071617767", token.INT, 0)),
		"SIOCGIFNUM":                    reflect.ValueOf(constant.MakeFromLiteral("1074030935", token.INT, 0)),
		"SIOCGIP6ADDRPOLICY":            reflect.ValueOf(constant.MakeFromLiteral("-1073714782", token.INT, 0)),
		"SIOCGIPMSFILTER":               reflect.ValueOf(constant.MakeFromLiteral("-1073452620", token.INT, 0)),
		"SIOCGLIFADDR":                  reflect.ValueOf(constant.MakeFromLiteral("-1065850511", token.INT, 0)),
		"SIOCGLIFBINDING":               reflect.ValueOf(constant.MakeFromLiteral("-1065850470", token.INT, 0)),
		"SIOCGLIFBRDADDR":               reflect.ValueOf(constant.MakeFromLiteral("-1065850501", token.INT, 0)),
		"SIOCGLIFCONF":                  reflect.ValueOf(constant.MakeFromLiteral("-1072666203", token.INT, 0)),
		"SIOCGLIFDADSTATE":              reflect.ValueOf(constant.MakeFromLiteral("-1065850434", token.INT, 0)),
		"SIOCGLIFDSTADDR":               reflect.ValueOf(constant.MakeFromLiteral("-1065850509", token.INT, 0)),
		"SIOCGLIFFLAGS":                 reflect.ValueOf(constant.MakeFromLiteral("-1065850507", token.INT, 0)),
		"SIOCGLIFGROUPINFO":             reflect.ValueOf(constant.MakeFromLiteral("-1061918307", token.INT, 0)),
		"SIOCGLIFGROUPNAME":             reflect.ValueOf(constant.MakeFromLiteral("-1065850468", token.INT, 0)),
		"SIOCGLIFHWADDR":                reflect.ValueOf(constant.MakeFromLiteral("-1065850432", token.INT, 0)),
		"SIOCGLIFINDEX":                 reflect.ValueOf(constant.MakeFromLiteral("-1065850491", token.INT, 0)),
		"SIOCGLIFLNKINFO":               reflect.ValueOf(constant.MakeFromLiteral("-1065850484", token.INT, 0)),
		"SIOCGLIFMETRIC":                reflect.ValueOf(constant.MakeFromLiteral("-1065850497", token.INT, 0)),
		"SIOCGLIFMTU":                   reflect.ValueOf(constant.MakeFromLiteral("-1065850502", token.INT, 0)),
		"SIOCGLIFMUXID":                 reflect.ValueOf(constant.MakeFromLiteral("-1065850493", token.INT, 0)),
		"SIOCGLIFNETMASK":               reflect.ValueOf(constant.MakeFromLiteral("-1065850499", token.INT, 0)),
		"SIOCGLIFNUM":                   reflect.ValueOf(constant.MakeFromLiteral("-1072928382", token.INT, 0)),
		"SIOCGLIFSRCOF":                 reflect.ValueOf(constant.MakeFromLiteral("-1072666191", token.INT, 0)),
		"SIOCGLIFSUBNET":                reflect.ValueOf(constant.MakeFromLiteral("-1065850486", token.INT, 0)),
		"SIOCGLIFTOKEN":                 reflect.ValueOf(constant.MakeFromLiteral("-1065850488", token.INT, 0)),
		"SIOCGLIFUSESRC":                reflect.ValueOf(constant.MakeFromLiteral("-1065850449", token.INT, 0)),
		"SIOCGLIFZONE":                  reflect.ValueOf(constant.MakeFromLiteral("-1065850454", token.INT, 0)),
		"SIOCGLOWAT":                    reflect.ValueOf(constant.MakeFromLiteral("1074033411", token.INT, 0)),
		"SIOCGMSFILTER":                 reflect.ValueOf(constant.MakeFromLiteral("-1073452622", token.INT, 0)),
		"SIOCGPGRP":                     reflect.ValueOf(constant.MakeFromLiteral("1074033417", token.INT, 0)),
		"SIOCGSTAMP":                    reflect.ValueOf(constant.MakeFromLiteral("-1072666182", token.INT, 0)),
		"SIOCGXARP":                     reflect.ValueOf(constant.MakeFromLiteral("-1073714777", token.INT, 0)),
		"SIOCIFDETACH":                  reflect.ValueOf(constant.MakeFromLiteral("-2145359560", token.INT, 0)),
		"SIOCILB":                       reflect.ValueOf(constant.MakeFromLiteral("-1073452613", token.INT, 0)),
		"SIOCLIFADDIF":                  reflect.ValueOf(constant.MakeFromLiteral("-1065850513", token.INT, 0)),
		"SIOCLIFDELND":                  reflect.ValueOf(constant.MakeFromLiteral("-2139592307", token.INT, 0)),
		"SIOCLIFGETND":                  reflect.ValueOf(constant.MakeFromLiteral("-1065850482", token.INT, 0)),
		"SIOCLIFREMOVEIF":               reflect.ValueOf(constant.MakeFromLiteral("-2139592338", token.INT, 0)),
		"SIOCLIFSETND":                  reflect.ValueOf(constant.MakeFromLiteral("-2139592305", token.INT, 0)),
		"SIOCLIPSECONFIG":               reflect.ValueOf(constant.MakeFromLiteral("-2147194472", token.INT, 0)),
		"SIOCLOWER":                     reflect.ValueOf(constant.MakeFromLiteral("-2145359575", token.INT, 0)),
		"SIOCSARP":                      reflect.ValueOf(constant.MakeFromLiteral("-2145097442", token.INT, 0)),
		"SIOCSCTPGOPT":                  reflect.ValueOf(constant.MakeFromLiteral("-1072666195", token.INT, 0)),
		"SIOCSCTPPEELOFF":               reflect.ValueOf(constant.MakeFromLiteral("-1073452626", token.INT, 0)),
		"SIOCSCTPSOPT":                  reflect.ValueOf(constant.MakeFromLiteral("-2146408020", token.INT, 0)),
		"SIOCSENABLESDP":                reflect.ValueOf(constant.MakeFromLiteral("-1073452617", token.INT, 0)),
		"SIOCSETPROP":                   reflect.ValueOf(constant.MakeFromLiteral("-2147192643", token.INT, 0)),
		"SIOCSETSYNC":                   reflect.ValueOf(constant.MakeFromLiteral("-2145359572", token.INT, 0)),
		"SIOCSHIWAT":                    reflect.ValueOf(constant.MakeFromLiteral("-2147192064", token.INT, 0)),
		"SIOCSIFADDR":                   reflect.ValueOf(constant.MakeFromLiteral("-2145359604", token.INT, 0)),
		"SIOCSIFBRDADDR":                reflect.ValueOf(constant.MakeFromLiteral("-2145359592", token.INT, 0)),
		"SIOCSIFDSTADDR":                reflect.ValueOf(constant.MakeFromLiteral("-2145359602", token.INT, 0)),
		"SIOCSIFFLAGS":                  reflect.ValueOf(constant.MakeFromLiteral("-2145359600", token.INT, 0)),
		"SIOCSIFINDEX":                  reflect.ValueOf(constant.MakeFromLiteral("-2145359525", token.INT, 0)),
		"SIOCSIFMEM":                    reflect.ValueOf(constant.MakeFromLiteral("-2145359598", token.INT, 0)),
		"SIOCSIFMETRIC":                 reflect.ValueOf(constant.MakeFromLiteral("-2145359588", token.INT, 0)),
		"SIOCSIFMTU":                    reflect.ValueOf(constant.MakeFromLiteral("-2145359595", token.INT, 0)),
		"SIOCSIFMUXID":                  reflect.ValueOf(constant.MakeFromLiteral("-2145359527", token.INT, 0)),
		"SIOCSIFNAME":                   reflect.ValueOf(constant.MakeFromLiteral("-2145359543", token.INT, 0)),
		"SIOCSIFNETMASK":                reflect.ValueOf(constant.MakeFromLiteral("-2145359590", token.INT, 0)),
		"SIOCSIP6ADDRPOLICY":            reflect.ValueOf(constant.MakeFromLiteral("-2147456605", token.INT, 0)),
		"SIOCSIPMSFILTER":               reflect.ValueOf(constant.MakeFromLiteral("-2147194443", token.INT, 0)),
		"SIOCSIPSECONFIG":               reflect.ValueOf(constant.MakeFromLiteral("-2147194474", token.INT, 0)),
		"SIOCSLGETREQ":                  reflect.ValueOf(constant.MakeFromLiteral("-1071617721", token.INT, 0)),
		"SIOCSLIFADDR":                  reflect.ValueOf(constant.MakeFromLiteral("-2139592336", token.INT, 0)),
		"SIOCSLIFBRDADDR":               reflect.ValueOf(constant.MakeFromLiteral("-2139592324", token.INT, 0)),
		"SIOCSLIFDSTADDR":               reflect.ValueOf(constant.MakeFromLiteral("-2139592334", token.INT, 0)),
		"SIOCSLIFFLAGS":                 reflect.ValueOf(constant.MakeFromLiteral("-2139592332", token.INT, 0)),
		"SIOCSLIFGROUPNAME":             reflect.ValueOf(constant.MakeFromLiteral("-2139592293", token.INT, 0)),
		"SIOCSLIFINDEX":                 reflect.ValueOf(constant.MakeFromLiteral("-2139592314", token.INT, 0)),
		"SIOCSLIFLNKINFO":               reflect.ValueOf(constant.MakeFromLiteral("-2139592309", token.INT, 0)),
		"SIOCSLIFMETRIC":                reflect.ValueOf(constant.MakeFromLiteral("-2139592320", token.INT, 0)),
		"SIOCSLIFMTU":                   reflect.ValueOf(constant.MakeFromLiteral("-2139592327", token.INT, 0)),
		"SIOCSLIFMUXID":                 reflect.ValueOf(constant.MakeFromLiteral("-2139592316", token.INT, 0)),
		"SIOCSLIFNAME":                  reflect.ValueOf(constant.MakeFromLiteral("-1065850495", token.INT, 0)),
		"SIOCSLIFNETMASK":               reflect.ValueOf(constant.MakeFromLiteral("-2139592322", token.INT, 0)),
		"SIOCSLIFPREFIX":                reflect.ValueOf(constant.MakeFromLiteral("-1065850433", token.INT, 0)),
		"SIOCSLIFSUBNET":                reflect.ValueOf(constant.MakeFromLiteral("-2139592311", token.INT, 0)),
		"SIOCSLIFTOKEN":                 reflect.ValueOf(constant.MakeFromLiteral("-2139592313", token.INT, 0)),
		"SIOCSLIFUSESRC":                reflect.ValueOf(constant.MakeFromLiteral("-2139592272", token.INT, 0)),
		"SIOCSLIFZONE":                  reflect.ValueOf(constant.MakeFromLiteral("-2139592277", token.INT, 0)),
		"SIOCSLOWAT":                    reflect.ValueOf(constant.MakeFromLiteral("-2147192062", token.INT, 0)),
		"SIOCSLSTAT":                    reflect.ValueOf(constant.MakeFromLiteral("-2145359544", token.INT, 0)),
		"SIOCSMSFILTER":                 reflect.ValueOf(constant.MakeFromLiteral("-2147194445", token.INT, 0)),
		"SIOCSPGRP":                     reflect.ValueOf(constant.MakeFromLiteral("-2147192056", token.INT, 0)),
		"SIOCSPROMISC":                  reflect.ValueOf(constant.MakeFromLiteral("-2147194576", token.INT, 0)),
		"SIOCSQPTR":                     reflect.ValueOf(constant.MakeFromLiteral("-1073452616", token.INT, 0)),
		"SIOCSSDSTATS":                  reflect.ValueOf(constant.MakeFromLiteral("-1071617746", token.INT, 0)),
		"SIOCSSESTATS":                  reflect.ValueOf(constant.MakeFromLiteral("-1071617745", token.INT, 0)),
		"SIOCSXARP":                     reflect.ValueOf(constant.MakeFromLiteral("-2147456602", token.INT, 0)),
		"SIOCTMYADDR":                   reflect.ValueOf(constant.MakeFromLiteral("-1073190512", token.INT, 0)),
		"SIOCTMYSITE":                   reflect.ValueOf(constant.MakeFromLiteral("-1073190510", token.INT, 0)),
		"SIOCTONLINK":                   reflect.ValueOf(constant.MakeFromLiteral("-1073190511", token.INT, 0)),
		"SIOCUPPER":                     reflect.ValueOf(constant.MakeFromLiteral("-2145359576", token.INT, 0)),
		"SIOCX25RCV":                    reflect.ValueOf(constant.MakeFromLiteral("-1071617732", token.INT, 0)),
		"SIOCX25TBL":                    reflect.ValueOf(constant.MakeFromLiteral("-1071617731", token.INT, 0)),
		"SIOCX25XMT":                    reflect.ValueOf(constant.MakeFromLiteral("-1071617733", token.INT, 0)),
		"SIOCXPROTO":                    reflect.ValueOf(constant.MakeFromLiteral("536900407", token.INT, 0)),
		"SOCK_CLOEXEC":                  reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"SOCK_DGRAM":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SOCK_NDELAY":                   reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"SOCK_NONBLOCK":                 reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"SOCK_RAW":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SOCK_RDM":                      reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"SOCK_SEQPACKET":                reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"SOCK_STREAM":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SOCK_TYPE_MASK":                reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"SOL_FILTER":                    reflect.ValueOf(constant.MakeFromLiteral("65532", token.INT, 0)),
		"SOL_PACKET":                    reflect.ValueOf(constant.MakeFromLiteral("65533", token.INT, 0)),
		"SOL_ROUTE":                     reflect.ValueOf(constant.MakeFromLiteral("65534", token.INT, 0)),
		"SOL_SOCKET":                    reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"SOMAXCONN":                     reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"SO_ACCEPTCONN":                 reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SO_ALL":                        reflect.ValueOf(constant.MakeFromLiteral("63", token.INT, 0)),
		"SO_ALLZONES":                   reflect.ValueOf(constant.MakeFromLiteral("4116", token.INT, 0)),
		"SO_ANON_MLP":                   reflect.ValueOf(constant.MakeFromLiteral("4106", token.INT, 0)),
		"SO_ATTACH_FILTER":              reflect.ValueOf(constant.MakeFromLiteral("1073741825", token.INT, 0)),
		"SO_BAND":                       reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"SO_BROADCAST":                  reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SO_COPYOPT":                    reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"SO_DEBUG":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SO_DELIM":                      reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"SO_DETACH_FILTER":              reflect.ValueOf(constant.MakeFromLiteral("1073741826", token.INT, 0)),
		"SO_DGRAM_ERRIND":               reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"SO_DOMAIN":                     reflect.ValueOf(constant.MakeFromLiteral("4108", token.INT, 0)),
		"SO_DONTLINGER":                 reflect.ValueOf(constant.MakeFromLiteral("-129", token.INT, 0)),
		"SO_DONTROUTE":                  reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SO_ERROPT":                     reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"SO_ERROR":                      reflect.ValueOf(constant.MakeFromLiteral("4103", token.INT, 0)),
		"SO_EXCLBIND":                   reflect.ValueOf(constant.MakeFromLiteral("4117", token.INT, 0)),
		"SO_HIWAT":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SO_ISNTTY":                     reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"SO_ISTTY":                      reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"SO_KEEPALIVE":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SO_LINGER":                     reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"SO_LOWAT":                      reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SO_MAC_EXEMPT":                 reflect.ValueOf(constant.MakeFromLiteral("4107", token.INT, 0)),
		"SO_MAC_IMPLICIT":               reflect.ValueOf(constant.MakeFromLiteral("4118", token.INT, 0)),
		"SO_MAXBLK":                     reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"SO_MAXPSZ":                     reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SO_MINPSZ":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SO_MREADOFF":                   reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"SO_MREADON":                    reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"SO_NDELOFF":                    reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"SO_NDELON":                     reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"SO_NODELIM":                    reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"SO_OOBINLINE":                  reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"SO_PROTOTYPE":                  reflect.ValueOf(constant.MakeFromLiteral("4105", token.INT, 0)),
		"SO_RCVBUF":                     reflect.ValueOf(constant.MakeFromLiteral("4098", token.INT, 0)),
		"SO_RCVLOWAT":                   reflect.ValueOf(constant.MakeFromLiteral("4100", token.INT, 0)),
		"SO_RCVPSH":                     reflect.ValueOf(constant.MakeFromLiteral("4109", token.INT, 0)),
		"SO_RCVTIMEO":                   reflect.ValueOf(constant.MakeFromLiteral("4102", token.INT, 0)),
		"SO_READOPT":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SO_RECVUCRED":                  reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"SO_REUSEADDR":                  reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SO_SECATTR":                    reflect.ValueOf(constant.MakeFromLiteral("4113", token.INT, 0)),
		"SO_SNDBUF":                     reflect.ValueOf(constant.MakeFromLiteral("4097", token.INT, 0)),
		"SO_SNDLOWAT":                   reflect.ValueOf(constant.MakeFromLiteral("4099", token.INT, 0)),
		"SO_SNDTIMEO":                   reflect.ValueOf(constant.MakeFromLiteral("4101", token.INT, 0)),
		"SO_STRHOLD":                    reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"SO_TAIL":                       reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"SO_TIMESTAMP":                  reflect.ValueOf(constant.MakeFromLiteral("4115", token.INT, 0)),
		"SO_TONSTOP":                    reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"SO_TOSTOP":                     reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"SO_TYPE":                       reflect.ValueOf(constant.MakeFromLiteral("4104", token.INT, 0)),
		"SO_USELOOPBACK":                reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"SO_VRRP":                       reflect.ValueOf(constant.MakeFromLiteral("4119", token.INT, 0)),
		"SO_WROFF":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SYS_EXECVE":                    reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"SYS_FCNTL":                     reflect.ValueOf(constant.MakeFromLiteral("62", token.INT, 0)),
		"S_IFBLK":                       reflect.ValueOf(constant.MakeFromLiteral("24576", token.INT, 0)),
		"S_IFCHR":                       reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"S_IFDIR":                       reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"S_IFIFO":                       reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"S_IFLNK":                       reflect.ValueOf(constant.MakeFromLiteral("40960", token.INT, 0)),
		"S_IFMT":                        reflect.ValueOf(constant.MakeFromLiteral("61440", token.INT, 0)),
		"S_IFREG":                       reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"S_IFSOCK":                      reflect.ValueOf(constant.MakeFromLiteral("49152", token.INT, 0)),
		"S_IRUSR":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"S_IRWXG":                       reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"S_IRWXO":                       reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"S_ISGID":                       reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"S_ISUID":                       reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"S_ISVTX":                       reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"S_IWUSR":                       reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"S_IXUSR":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"Seek":                          reflect.ValueOf(syscall.Seek),
		"Sendfile":                      reflect.ValueOf(syscall.Sendfile),
		"Sendmsg":                       reflect.ValueOf(syscall.Sendmsg),
		"SendmsgN":                      reflect.ValueOf(syscall.SendmsgN),
		"Sendto":                        reflect.ValueOf(syscall.Sendto),
		"SetNonblock":                   reflect.ValueOf(syscall.SetNonblock),
		"Setegid":                       reflect.ValueOf(syscall.Setegid),
		"Setenv":                        reflect.ValueOf(syscall.Setenv),
		"Seteuid":                       reflect.ValueOf(syscall.Seteuid),
		"Setgid":                        reflect.ValueOf(syscall.Setgid),
		"Setgroups":                     reflect.ValueOf(syscall.Setgroups),
		"Setpgid":                       reflect.ValueOf(syscall.Setpgid),
		"Setpriority":                   reflect.ValueOf(syscall.Setpriority),
		"Setregid":                      reflect.ValueOf(syscall.Setregid),
		"Setreuid":                      reflect.ValueOf(syscall.Setreuid),
		"Setrlimit":                     reflect.ValueOf(syscall.Setrlimit),
		"Setsid":                        reflect.ValueOf(syscall.Setsid),
		"SetsockoptByte":                reflect.ValueOf(syscall.SetsockoptByte),
		"SetsockoptICMPv6Filter":        reflect.ValueOf(syscall.SetsockoptICMPv6Filter),
		"SetsockoptIPMreq":              reflect.ValueOf(syscall.SetsockoptIPMreq),
		"SetsockoptIPv6Mreq":            reflect.ValueOf(syscall.SetsockoptIPv6Mreq),
		"SetsockoptInet4Addr":           reflect.ValueOf(syscall.SetsockoptInet4Addr),
		"SetsockoptInt":                 reflect.ValueOf(syscall.SetsockoptInt),
		"SetsockoptLinger":              reflect.ValueOf(syscall.SetsockoptLinger),
		"SetsockoptString":              reflect.ValueOf(syscall.SetsockoptString),
		"SetsockoptTimeval":             reflect.ValueOf(syscall.SetsockoptTimeval),
		"Setuid":                        reflect.ValueOf(syscall.Setuid),
		"SizeofBpfHdr":                  reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SizeofBpfInsn":                 reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofBpfProgram":              reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SizeofBpfStat":                 reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"SizeofBpfVersion":              reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SizeofCmsghdr":                 reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"SizeofICMPv6Filter":            reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SizeofIPMreq":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofIPv6MTUInfo":             reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"SizeofIPv6Mreq":                reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SizeofIfData":                  reflect.ValueOf(constant.MakeFromLiteral("68", token.INT, 0)),
		"SizeofIfMsghdr":                reflect.ValueOf(constant.MakeFromLiteral("84", token.INT, 0)),
		"SizeofIfaMsghdr":               reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SizeofInet6Pktinfo":            reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SizeofLinger":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofMsghdr":                  reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"SizeofRtMetrics":               reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"SizeofRtMsghdr":                reflect.ValueOf(constant.MakeFromLiteral("76", token.INT, 0)),
		"SizeofSockaddrAny":             reflect.ValueOf(constant.MakeFromLiteral("252", token.INT, 0)),
		"SizeofSockaddrDatalink":        reflect.ValueOf(constant.MakeFromLiteral("252", token.INT, 0)),
		"SizeofSockaddrInet4":           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SizeofSockaddrInet6":           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SizeofSockaddrUnix":            reflect.ValueOf(constant.MakeFromLiteral("110", token.INT, 0)),
		"SlicePtrFromStrings":           reflect.ValueOf(syscall.SlicePtrFromStrings),
		"Socket":                        reflect.ValueOf(syscall.Socket),
		"SocketDisableIPv6":             reflect.ValueOf(&syscall.SocketDisableIPv6).Elem(),
		"Socketpair":                    reflect.ValueOf(syscall.Socketpair),
		"Stat":                          reflect.ValueOf(syscall.Stat),
		"Stderr":                        reflect.ValueOf(&syscall.Stderr).Elem(),
		"Stdin":                         reflect.ValueOf(&syscall.Stdin).Elem(),
		"Stdout":                        reflect.ValueOf(&syscall.Stdout).Elem(),
		"StringBytePtr":                 reflect.ValueOf(syscall.StringBytePtr),
		"StringByteSlice":               reflect.ValueOf(syscall.StringByteSlice),
		"StringSlicePtr":                reflect.ValueOf(syscall.StringSlicePtr),
		"Symlink":                       reflect.ValueOf(syscall.Symlink),
		"Sync":                          reflect.ValueOf(syscall.Sync),
		"TCFLSH":                        reflect.ValueOf(constant.MakeFromLiteral("21511", token.INT, 0)),
		"TCIFLUSH":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"TCIOFLUSH":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TCOFLUSH":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TCP_ABORT_THRESHOLD":           reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"TCP_ANONPRIVBIND":              reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"TCP_CONN_ABORT_THRESHOLD":      reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"TCP_CONN_NOTIFY_THRESHOLD":     reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"TCP_CORK":                      reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"TCP_EXCLBIND":                  reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"TCP_INIT_CWND":                 reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"TCP_KEEPALIVE":                 reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TCP_KEEPALIVE_ABORT_THRESHOLD": reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"TCP_KEEPALIVE_THRESHOLD":       reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"TCP_KEEPCNT":                   reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"TCP_KEEPIDLE":                  reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"TCP_KEEPINTVL":                 reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"TCP_LINGER2":                   reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"TCP_MAXSEG":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TCP_MSS":                       reflect.ValueOf(constant.MakeFromLiteral("536", token.INT, 0)),
		"TCP_NODELAY":                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TCP_NOTIFY_THRESHOLD":          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TCP_RECVDSTADDR":               reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"TCP_RTO_INITIAL":               reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"TCP_RTO_MAX":                   reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"TCP_RTO_MIN":                   reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"TCSAFLUSH":                     reflect.ValueOf(constant.MakeFromLiteral("21520", token.INT, 0)),
		"TIOC":                          reflect.ValueOf(constant.MakeFromLiteral("21504", token.INT, 0)),
		"TIOCCBRK":                      reflect.ValueOf(constant.MakeFromLiteral("29818", token.INT, 0)),
		"TIOCCDTR":                      reflect.ValueOf(constant.MakeFromLiteral("29816", token.INT, 0)),
		"TIOCCILOOP":                    reflect.ValueOf(constant.MakeFromLiteral("29804", token.INT, 0)),
		"TIOCEXCL":                      reflect.ValueOf(constant.MakeFromLiteral("29709", token.INT, 0)),
		"TIOCFLUSH":                     reflect.ValueOf(constant.MakeFromLiteral("29712", token.INT, 0)),
		"TIOCGETC":                      reflect.ValueOf(constant.MakeFromLiteral("29714", token.INT, 0)),
		"TIOCGETD":                      reflect.ValueOf(constant.MakeFromLiteral("29696", token.INT, 0)),
		"TIOCGETP":                      reflect.ValueOf(constant.MakeFromLiteral("29704", token.INT, 0)),
		"TIOCGLTC":                      reflect.ValueOf(constant.MakeFromLiteral("29812", token.INT, 0)),
		"TIOCGPGRP":                     reflect.ValueOf(constant.MakeFromLiteral("29716", token.INT, 0)),
		"TIOCGPPS":                      reflect.ValueOf(constant.MakeFromLiteral("21629", token.INT, 0)),
		"TIOCGPPSEV":                    reflect.ValueOf(constant.MakeFromLiteral("21631", token.INT, 0)),
		"TIOCGSID":                      reflect.ValueOf(constant.MakeFromLiteral("29718", token.INT, 0)),
		"TIOCGSOFTCAR":                  reflect.ValueOf(constant.MakeFromLiteral("21609", token.INT, 0)),
		"TIOCGWINSZ":                    reflect.ValueOf(constant.MakeFromLiteral("21608", token.INT, 0)),
		"TIOCHPCL":                      reflect.ValueOf(constant.MakeFromLiteral("29698", token.INT, 0)),
		"TIOCKBOF":                      reflect.ValueOf(constant.MakeFromLiteral("21513", token.INT, 0)),
		"TIOCKBON":                      reflect.ValueOf(constant.MakeFromLiteral("21512", token.INT, 0)),
		"TIOCLBIC":                      reflect.ValueOf(constant.MakeFromLiteral("29822", token.INT, 0)),
		"TIOCLBIS":                      reflect.ValueOf(constant.MakeFromLiteral("29823", token.INT, 0)),
		"TIOCLGET":                      reflect.ValueOf(constant.MakeFromLiteral("29820", token.INT, 0)),
		"TIOCLSET":                      reflect.ValueOf(constant.MakeFromLiteral("29821", token.INT, 0)),
		"TIOCMBIC":                      reflect.ValueOf(constant.MakeFromLiteral("29724", token.INT, 0)),
		"TIOCMBIS":                      reflect.ValueOf(constant.MakeFromLiteral("29723", token.INT, 0)),
		"TIOCMGET":                      reflect.ValueOf(constant.MakeFromLiteral("29725", token.INT, 0)),
		"TIOCMSET":                      reflect.ValueOf(constant.MakeFromLiteral("29722", token.INT, 0)),
		"TIOCM_CAR":                     reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"TIOCM_CD":                      reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"TIOCM_CTS":                     reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"TIOCM_DSR":                     reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"TIOCM_DTR":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TIOCM_LE":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TIOCM_RI":                      reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"TIOCM_RNG":                     reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"TIOCM_RTS":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TIOCM_SR":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TIOCM_ST":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TIOCNOTTY":                     reflect.ValueOf(constant.MakeFromLiteral("29809", token.INT, 0)),
		"TIOCNXCL":                      reflect.ValueOf(constant.MakeFromLiteral("29710", token.INT, 0)),
		"TIOCOUTQ":                      reflect.ValueOf(constant.MakeFromLiteral("29811", token.INT, 0)),
		"TIOCREMOTE":                    reflect.ValueOf(constant.MakeFromLiteral("29726", token.INT, 0)),
		"TIOCSBRK":                      reflect.ValueOf(constant.MakeFromLiteral("29819", token.INT, 0)),
		"TIOCSCTTY":                     reflect.ValueOf(constant.MakeFromLiteral("29828", token.INT, 0)),
		"TIOCSDTR":                      reflect.ValueOf(constant.MakeFromLiteral("29817", token.INT, 0)),
		"TIOCSETC":                      reflect.ValueOf(constant.MakeFromLiteral("29713", token.INT, 0)),
		"TIOCSETD":                      reflect.ValueOf(constant.MakeFromLiteral("29697", token.INT, 0)),
		"TIOCSETN":                      reflect.ValueOf(constant.MakeFromLiteral("29706", token.INT, 0)),
		"TIOCSETP":                      reflect.ValueOf(constant.MakeFromLiteral("29705", token.INT, 0)),
		"TIOCSIGNAL":                    reflect.ValueOf(constant.MakeFromLiteral("29727", token.INT, 0)),
		"TIOCSILOOP":                    reflect.ValueOf(constant.MakeFromLiteral("29805", token.INT, 0)),
		"TIOCSLTC":                      reflect.ValueOf(constant.MakeFromLiteral("29813", token.INT, 0)),
		"TIOCSPGRP":                     reflect.ValueOf(constant.MakeFromLiteral("29717", token.INT, 0)),
		"TIOCSPPS":                      reflect.ValueOf(constant.MakeFromLiteral("21630", token.INT, 0)),
		"TIOCSSOFTCAR":                  reflect.ValueOf(constant.MakeFromLiteral("21610", token.INT, 0)),
		"TIOCSTART":                     reflect.ValueOf(constant.MakeFromLiteral("29806", token.INT, 0)),
		"TIOCSTI":                       reflect.ValueOf(constant.MakeFromLiteral("29719", token.INT, 0)),
		"TIOCSTOP":                      reflect.ValueOf(constant.MakeFromLiteral("29807", token.INT, 0)),
		"TIOCSWINSZ":                    reflect.ValueOf(constant.MakeFromLiteral("21607", token.INT, 0)),
		"TOSTOP":                        reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"TimespecToNsec":                reflect.ValueOf(syscall.TimespecToNsec),
		"TimevalToNsec":                 reflect.ValueOf(syscall.TimevalToNsec),
		"Truncate":                      reflect.ValueOf(syscall.Truncate),
		"Umask":                         reflect.ValueOf(syscall.Umask),
		"UnixRights":                    reflect.ValueOf(syscall.UnixRights),
		"Unlink":                        reflect.ValueOf(syscall.Unlink),
		"Unsetenv":                      reflect.ValueOf(syscall.Unsetenv),
		"Utimes":                        reflect.ValueOf(syscall.Utimes),
		"UtimesNano":                    reflect.ValueOf(syscall.UtimesNano),
		"VCEOF":                         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"VCEOL":                         reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"VDISCARD":                      reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"VDSUSP":                        reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"VEOF":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"VEOL":                          reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"VEOL2":                         reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"VERASE":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"VINTR":                         reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"VKILL":                         reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"VLNEXT":                        reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"VMIN":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"VQUIT":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"VREPRINT":                      reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"VSTART":                        reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"VSTOP":                         reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"VSUSP":                         reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"VSWTCH":                        reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"VT0":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"VT1":                           reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"VTDLY":                         reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"VTIME":                         reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"VWERASE":                       reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"WCONTFLG":                      reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"WCONTINUED":                    reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"WCOREFLG":                      reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"WEXITED":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"WNOHANG":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"WNOWAIT":                       reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"WOPTMASK":                      reflect.ValueOf(constant.MakeFromLiteral("207", token.INT, 0)),
		"WRAP":                          reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"WSIGMASK":                      reflect.ValueOf(constant.MakeFromLiteral("127", token.INT, 0)),
		"WSTOPFLG":                      reflect.ValueOf(constant.MakeFromLiteral("127", token.INT, 0)),
		"WSTOPPED":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"WTRAPPED":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"WUNTRACED":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"Wait4":                         reflect.ValueOf(syscall.Wait4),
		"Write":                         reflect.ValueOf(syscall.Write),

		// type definitions
		"BpfHdr":               reflect.ValueOf((*syscall.BpfHdr)(nil)),
		"BpfInsn":              reflect.ValueOf((*syscall.BpfInsn)(nil)),
		"BpfProgram":           reflect.ValueOf((*syscall.BpfProgram)(nil)),
		"BpfStat":              reflect.ValueOf((*syscall.BpfStat)(nil)),
		"BpfTimeval":           reflect.ValueOf((*syscall.BpfTimeval)(nil)),
		"BpfVersion":           reflect.ValueOf((*syscall.BpfVersion)(nil)),
		"Cmsghdr":              reflect.ValueOf((*syscall.Cmsghdr)(nil)),
		"Conn":                 reflect.ValueOf((*syscall.Conn)(nil)),
		"Credential":           reflect.ValueOf((*syscall.Credential)(nil)),
		"Dirent":               reflect.ValueOf((*syscall.Dirent)(nil)),
		"Errno":                reflect.ValueOf((*syscall.Errno)(nil)),
		"FdSet":                reflect.ValueOf((*syscall.FdSet)(nil)),
		"Flock_t":              reflect.ValueOf((*syscall.Flock_t)(nil)),
		"ICMPv6Filter":         reflect.ValueOf((*syscall.ICMPv6Filter)(nil)),
		"IPMreq":               reflect.ValueOf((*syscall.IPMreq)(nil)),
		"IPv6MTUInfo":          reflect.ValueOf((*syscall.IPv6MTUInfo)(nil)),
		"IPv6Mreq":             reflect.ValueOf((*syscall.IPv6Mreq)(nil)),
		"IfData":               reflect.ValueOf((*syscall.IfData)(nil)),
		"IfMsghdr":             reflect.ValueOf((*syscall.IfMsghdr)(nil)),
		"IfaMsghdr":            reflect.ValueOf((*syscall.IfaMsghdr)(nil)),
		"Inet6Pktinfo":         reflect.ValueOf((*syscall.Inet6Pktinfo)(nil)),
		"Iovec":                reflect.ValueOf((*syscall.Iovec)(nil)),
		"Linger":               reflect.ValueOf((*syscall.Linger)(nil)),
		"Msghdr":               reflect.ValueOf((*syscall.Msghdr)(nil)),
		"ProcAttr":             reflect.ValueOf((*syscall.ProcAttr)(nil)),
		"RawConn":              reflect.ValueOf((*syscall.RawConn)(nil)),
		"RawSockaddr":          reflect.ValueOf((*syscall.RawSockaddr)(nil)),
		"RawSockaddrAny":       reflect.ValueOf((*syscall.RawSockaddrAny)(nil)),
		"RawSockaddrDatalink":  reflect.ValueOf((*syscall.RawSockaddrDatalink)(nil)),
		"RawSockaddrInet4":     reflect.ValueOf((*syscall.RawSockaddrInet4)(nil)),
		"RawSockaddrInet6":     reflect.ValueOf((*syscall.RawSockaddrInet6)(nil)),
		"RawSockaddrUnix":      reflect.ValueOf((*syscall.RawSockaddrUnix)(nil)),
		"Rlimit":               reflect.ValueOf((*syscall.Rlimit)(nil)),
		"RtMetrics":            reflect.ValueOf((*syscall.RtMetrics)(nil)),
		"RtMsghdr":             reflect.ValueOf((*syscall.RtMsghdr)(nil)),
		"Rusage":               reflect.ValueOf((*syscall.Rusage)(nil)),
		"Signal":               reflect.ValueOf((*syscall.Signal)(nil)),
		"Sockaddr":             reflect.ValueOf((*syscall.Sockaddr)(nil)),
		"SockaddrDatalink":     reflect.ValueOf((*syscall.SockaddrDatalink)(nil)),
		"SockaddrInet4":        reflect.ValueOf((*syscall.SockaddrInet4)(nil)),
		"SockaddrInet6":        reflect.ValueOf((*syscall.SockaddrInet6)(nil)),
		"SockaddrUnix":         reflect.ValueOf((*syscall.SockaddrUnix)(nil)),
		"SocketControlMessage": reflect.ValueOf((*syscall.SocketControlMessage)(nil)),
		"Stat_t":               reflect.ValueOf((*syscall.Stat_t)(nil)),
		"SysProcAttr":          reflect.ValueOf((*syscall.SysProcAttr)(nil)),
		"Termios":              reflect.ValueOf((*syscall.Termios)(nil)),
		"Timespec":             reflect.ValueOf((*syscall.Timespec)(nil)),
		"Timeval":              reflect.ValueOf((*syscall.Timeval)(nil)),
		"Timeval32":            reflect.ValueOf((*syscall.Timeval32)(nil)),
		"WaitStatus":           reflect.ValueOf((*syscall.WaitStatus)(nil)),

		// interface wrapper definitions
		"_Conn":     reflect.ValueOf((*_syscall_Conn)(nil)),
		"_RawConn":  reflect.ValueOf((*_syscall_RawConn)(nil)),
		"_Sockaddr": reflect.ValueOf((*_syscall_Sockaddr)(nil)),
	}
}

// _syscall_Conn is an interface wrapper for Conn type
type _syscall_Conn struct {
	IValue       interface{}
	WSyscallConn func() (syscall.RawConn, error)
}

func (W _syscall_Conn) SyscallConn() (syscall.RawConn, error) { return W.WSyscallConn() }

// _syscall_RawConn is an interface wrapper for RawConn type
type _syscall_RawConn struct {
	IValue   interface{}
	WControl func(f func(fd uintptr)) error
	WRead    func(f func(fd uintptr) (done bool)) error
	WWrite   func(f func(fd uintptr) (done bool)) error
}

func (W _syscall_RawConn) Control(f func(fd uintptr)) error           { return W.WControl(f) }
func (W _syscall_RawConn) Read(f func(fd uintptr) (done bool)) error  { return W.WRead(f) }
func (W _syscall_RawConn) Write(f func(fd uintptr) (done bool)) error { return W.WWrite(f) }

// _syscall_Sockaddr is an interface wrapper for Sockaddr type
type _syscall_Sockaddr struct {
	IValue interface{}
}
